# All Documents

- magneticalc
  index.html
  Package
  Package
  PUBLIC
  MagnetiCalc package initialization.
- magneticalc.API
  magneticalc.API.html
  Module
  Module
  PUBLIC
  API module.
- magneticalc.About_Dialog
  magneticalc.About_Dialog.html
  Module
  Module
  PUBLIC
  About_Dialog module.
- magneticalc.Assert_Dialog
  magneticalc.Assert_Dialog.html
  Module
  Module
  PUBLIC
  Assert_Dialog module.
- magneticalc.Backend_CUDA
  magneticalc.Backend_CUDA.html
  Module
  Module
  PUBLIC
  Backend_CUDA module.
- magneticalc.Backend_JIT
  magneticalc.Backend_JIT.html
  Module
  Module
  PUBLIC
  Backend_JIT module.
- magneticalc.Backend_Types
  magneticalc.Backend_Types.html
  Module
  Module
  PUBLIC
  Backend_Types module.
- magneticalc.CalculationThread
  magneticalc.CalculationThread.html
  Module
  Module
  PUBLIC
  CalculationThread module.
- magneticalc.CheckForUpdates_Dialog
  magneticalc.CheckForUpdates_Dialog.html
  Module
  Module
  PUBLIC
  CheckForUpdates_Dialog module.
- magneticalc.Comparison_Types
  magneticalc.Comparison_Types.html
  Module
  Module
  PUBLIC
  Comparison_Types module.
- magneticalc.ConditionalDecorator
  magneticalc.ConditionalDecorator.html
  Module
  Module
  PUBLIC
  ConditionalDecorator module.
- magneticalc.Config
  magneticalc.Config.html
  Module
  Module
  PUBLIC
  Config module.
- magneticalc.Config_Group
  magneticalc.Config_Group.html
  Module
  Module
  PUBLIC
  Config_Collection module.
- magneticalc.Constants
  magneticalc.Constants.html
  Module
  Module
  PUBLIC
  Constants module.
- magneticalc.Constraint
  magneticalc.Constraint.html
  Module
  Module
  PUBLIC
  Constraint module.
- magneticalc.Constraint_Editor
  magneticalc.Constraint_Editor.html
  Module
  Module
  PUBLIC
  Constraint_Editor module.
- magneticalc.Debug
  magneticalc.Debug.html
  Module
  Module
  PUBLIC
  Debug module.
- magneticalc.Display_Widget
  magneticalc.Display_Widget.html
  Module
  Module
  PUBLIC
  Display_Widget module.
- magneticalc.ExportContainer_Dialog
  magneticalc.ExportContainer_Dialog.html
  Module
  Module
  PUBLIC
  ExportContainer_Dialog module.
- magneticalc.Field
  magneticalc.Field.html
  Module
  Module
  PUBLIC
  Field module.
- magneticalc.Field_Types
  magneticalc.Field_Types.html
  Module
  Module
  PUBLIC
  Field_Types module.
- magneticalc.Field_Widget
  magneticalc.Field_Widget.html
  Module
  Module
  PUBLIC
  Field_Widget module.
- magneticalc.File_Menu
  magneticalc.File_Menu.html
  Module
  Module
  PUBLIC
  File_Menu module.
- magneticalc.Format
  magneticalc.Format.html
  Module
  Module
  PUBLIC
  Format module.
- magneticalc.GUI
  magneticalc.GUI.html
  Module
  Module
  PUBLIC
  GUI module.
- magneticalc.Help_Menu
  magneticalc.Help_Menu.html
  Module
  Module
  PUBLIC
  Help_Menu module.
- magneticalc.MagnetiCalc_Data
  magneticalc.MagnetiCalc_Data.html
  Module
  Module
  PUBLIC
  MagnetiCalc_Data module.
- magneticalc.Menu
  magneticalc.Menu.html
  Module
  Module
  PUBLIC
  Menu module.
- magneticalc.Metric
  magneticalc.Metric.html
  Module
  Module
  PUBLIC
  Metric module.
- magneticalc.Metric_Presets
  magneticalc.Metric_Presets.html
  Module
  Module
  PUBLIC
  Metric_Presets module.
- magneticalc.Metric_Widget
  magneticalc.Metric_Widget.html
  Module
  Module
  PUBLIC
  Metric_Widget module.
- magneticalc.Model
  magneticalc.Model.html
  Module
  Module
  PUBLIC
  Model module.
- magneticalc.ModelAccess
  magneticalc.ModelAccess.html
  Module
  Module
  PUBLIC
  Model access module.
- magneticalc.Norm_Types
  magneticalc.Norm_Types.html
  Module
  Module
  PUBLIC
  Norm_Types module.
- magneticalc.Options_Menu
  magneticalc.Options_Menu.html
  Module
  Module
  PUBLIC
  Options_Menu module.
- magneticalc.OverridePadding_Dialog
  magneticalc.OverridePadding_Dialog.html
  Module
  Module
  PUBLIC
  OverridePadding_Dialog module.
- magneticalc.Parameters
  magneticalc.Parameters.html
  Module
  Module
  PUBLIC
  Parameters module.
- magneticalc.Parameters_Widget
  magneticalc.Parameters_Widget.html
  Module
  Module
  PUBLIC
  Parameters_Widget module.
- magneticalc.Perspective_Presets
  magneticalc.Perspective_Presets.html
  Module
  Module
  PUBLIC
  Perspective_Presets module.
- magneticalc.Perspective_Widget
  magneticalc.Perspective_Widget.html
  Module
  Module
  PUBLIC
  Perspective_Widget module.
- magneticalc.Project
  magneticalc.Project.html
  Module
  Module
  PUBLIC
  Project module.
- magneticalc.QCheckboxConfig
  magneticalc.QCheckboxConfig.html
  Module
  Module
  PUBLIC
  QCheckboxConfig module.
- magneticalc.QMessageBox2
  magneticalc.QMessageBox2.html
  Module
  Module
  PUBLIC
  QMessageBox2 module.
- magneticalc.QTableView2
  magneticalc.QTableView2.html
  Module
  Module
  PUBLIC
  QTableView2 module.
- magneticalc.QtWidgets2
  magneticalc.QtWidgets2.html
  Package
  Package
  PUBLIC
  MagnetiCalc package initialization.
- magneticalc.QtWidgets2.QButtons
  magneticalc.QtWidgets2.QButtons.html
  Module
  Module
  PUBLIC
  QButtons module.
- magneticalc.QtWidgets2.QDialog2
  magneticalc.QtWidgets2.QDialog2.html
  Module
  Module
  PUBLIC
  QDialog2 module.
- magneticalc.QtWidgets2.QDoubleSpinBox2
  magneticalc.QtWidgets2.QDoubleSpinBox2.html
  Module
  Module
  PUBLIC
  QDoubleSpinBox2 module.
- magneticalc.QtWidgets2.QGroupBox2
  magneticalc.QtWidgets2.QGroupBox2.html
  Module
  Module
  PUBLIC
  QGroupBox2 module.
- magneticalc.QtWidgets2.QHBoxLayout2
  magneticalc.QtWidgets2.QHBoxLayout2.html
  Module
  Module
  PUBLIC
  QHBoxLayout2 module.
- magneticalc.QtWidgets2.QHLine
  magneticalc.QtWidgets2.QHLine.html
  Module
  Module
  PUBLIC
  QHLine module.
- magneticalc.QtWidgets2.QIconLabel
  magneticalc.QtWidgets2.QIconLabel.html
  Module
  Module
  PUBLIC
  QIconLabel module.
- magneticalc.QtWidgets2.QLabel2
  magneticalc.QtWidgets2.QLabel2.html
  Module
  Module
  PUBLIC
  QLabel2 module.
- magneticalc.QtWidgets2.QLayouted
  magneticalc.QtWidgets2.QLayouted.html
  Module
  Module
  PUBLIC
  QLayouted module.
- magneticalc.QtWidgets2.QPushButton2
  magneticalc.QtWidgets2.QPushButton2.html
  Module
  Module
  PUBLIC
  QPushButton2 module.
- magneticalc.QtWidgets2.QSaveAction
  magneticalc.QtWidgets2.QSaveAction.html
  Module
  Module
  PUBLIC
  QSaveAction module.
- magneticalc.QtWidgets2.QSliderFloat
  magneticalc.QtWidgets2.QSliderFloat.html
  Module
  Module
  PUBLIC
  QSliderFloat module.
- magneticalc.QtWidgets2.QSpinBox2
  magneticalc.QtWidgets2.QSpinBox2.html
  Module
  Module
  PUBLIC
  QSpinBox2 module.
- magneticalc.QtWidgets2.QTextBrowser2
  magneticalc.QtWidgets2.QTextBrowser2.html
  Module
  Module
  PUBLIC
  QTextBrowser2 module.
- magneticalc.SamplingVolume
  magneticalc.SamplingVolume.html
  Module
  Module
  PUBLIC
  Sampling volume module.
- magneticalc.SamplingVolume_Widget
  magneticalc.SamplingVolume_Widget.html
  Module
  Module
  PUBLIC
  SamplingVolume_Widget module.
- magneticalc.SidebarLeft
  magneticalc.SidebarLeft.html
  Module
  Module
  PUBLIC
  SidebarLeft module.
- magneticalc.SidebarRight
  magneticalc.SidebarRight.html
  Module
  Module
  PUBLIC
  SidebarRight module.
- magneticalc.Statusbar
  magneticalc.Statusbar.html
  Module
  Module
  PUBLIC
  Statusbar module.
- magneticalc.Theme
  magneticalc.Theme.html
  Module
  Module
  PUBLIC
  Theme module.
- magneticalc.Usage_Dialog
  magneticalc.Usage_Dialog.html
  Module
  Module
  PUBLIC
  Usage_Dialog module.
- magneticalc.Validatable
  magneticalc.Validatable.html
  Module
  Module
  PUBLIC
  Validatable module.
- magneticalc.Version
  magneticalc.Version.html
  Module
  Module
  PUBLIC
  Version module.
- magneticalc.View_Menu
  magneticalc.View_Menu.html
  Module
  Module
  PUBLIC
  View_Menu module.
- magneticalc.VisPyCanvas
  magneticalc.VisPyCanvas.html
  Module
  Module
  PUBLIC
  VisPyCanvas module.
- magneticalc.Wire
  magneticalc.Wire.html
  Module
  Module
  PUBLIC
  Wire module.
- magneticalc.Wire_Menu
  magneticalc.Wire_Menu.html
  Module
  Module
  PUBLIC
  Wire_Menu module.
- magneticalc.Wire_Presets
  magneticalc.Wire_Presets.html
  Module
  Module
  PUBLIC
  Wire_Presets module.
- magneticalc.Wire_Widget
  magneticalc.Wire_Widget.html
  Module
  Module
  PUBLIC
  Wire_Widget module.
- magneticalc.__main__
  magneticalc.__main__.html
  Module
  Module
  PRIVATE
  MagnetiCalc main module.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html
  Class
  Class
  PUBLIC
  MagnetiCalc_Data class.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__init__
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#__init__
  Function
  Method
  PUBLIC
  Initializes MagnetiCalc_Data class.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.dictionary
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#dictionary
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_wire
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_wire
  Function
  Method
  PUBLIC
  Gets the wire points as three separate 1D arrays (raveled).
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_wire_list
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_wire_list
  Function
  Method
  PUBLIC
  Gets the wire points as a single list of 3D points (raveled).
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_current
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_current
  Function
  Method
  PUBLIC
  Gets the wire current.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_dimension
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_dimension
  Function
  Method
  PUBLIC
  Gets the sampling volume dimension.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_axes
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_axes
  Function
  Method
  PUBLIC
  Gets the sampling volume axes as three separate 1D arrays (raveled).
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_axes_list
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_axes_list
  Function
  Method
  PUBLIC
  Gets the sampling volume axes as a single list of 3D points (raveled).
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_field
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_field
  Function
  Method
  PUBLIC
  Gets the field as three separate 1D arrays (raveled).
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_a_field
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_a_field
  Function
  Method
  PUBLIC
  Gets the A-field components as three separate 1D arrays (raveled). Please refer to `get_field()` for possible arguments.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_a_field_list
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_a_field_list
  Function
  Method
  PUBLIC
  Gets the A-field components as a single list of 3D points (raveled). Please refer to `get_field()` for possible arguments.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_b_field
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_b_field
  Function
  Method
  PUBLIC
  Gets the B-field components. Please refer to `get_field()` for possible arguments.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_b_field_list
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#get_b_field_list
  Function
  Method
  PUBLIC
  Gets the B-field components as a single list of 3D points (raveled). Please refer to `get_field()` for possible arguments.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data._get_fields
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#_get_fields
  Function
  Method
  PRIVATE
  Gets the raw "fields" dictionary from the data.
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__getitem__
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#__getitem__
  Function
  Method
  PUBLIC
  Undocumented
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__setitem__
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#__setitem__
  Function
  Method
  PUBLIC
  Undocumented
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__delitem__
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#__delitem__
  Function
  Method
  PUBLIC
  Undocumented
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__iter__
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#__iter__
  Function
  Method
  PUBLIC
  Undocumented
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__len__
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#__len__
  Function
  Method
  PUBLIC
  Undocumented
- magneticalc.MagnetiCalc_Data.MagnetiCalc_Data._keytransform
  magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.html#_keytransform
  Function
  Method
  PRIVATE
  Undocumented
- magneticalc.API.API
  magneticalc.API.API.html
  Class
  Class
  PUBLIC
  API class.
- magneticalc.API.API.import_wire
  magneticalc.API.API.html#import_wire
  Function
  Static Method
  PUBLIC
  Imports wire points from a TXT file.
- magneticalc.API.API.export_wire
  magneticalc.API.API.html#export_wire
  Function
  Static Method
  PUBLIC
  Exports wire points to a TXT file.
- magneticalc.API.API.import_hdf5
  magneticalc.API.API.html#import_hdf5
  Function
  Static Method
  PUBLIC
  Imports data from an HDF5 container.
- magneticalc.API.API.export_hdf5
  magneticalc.API.API.html#export_hdf5
  Function
  Static Method
  PUBLIC
  Exports data to an HDF5 container.
- magneticalc.API.API._dict_to_hdf5_group
  magneticalc.API.API.html#_dict_to_hdf5_group
  Function
  Static Method
  PRIVATE
  Recursively transforms a dictionary into an HDF5 group (in-place).
- magneticalc.API.API._hdf5_group_to_dict
  magneticalc.API.API.html#_hdf5_group_to_dict
  Function
  Static Method
  PRIVATE
  Recursively transforms an HDF5 group into a dictionary (in-place).
- magneticalc.QtWidgets2.QButtons.QButtons
  magneticalc.QtWidgets2.QButtons.QButtons.html
  Class
  Class
  PUBLIC
  QButtons class.
- magneticalc.QtWidgets2.QButtons.QButtons.__init__
  magneticalc.QtWidgets2.QButtons.QButtons.html#__init__
  Function
  Method
  PUBLIC
  Initializes a horizontal layout containing multiple buttons.
- magneticalc.QtWidgets2.QButtons.QButtons.dictionary
  magneticalc.QtWidgets2.QButtons.QButtons.html#dictionary
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.QtWidgets2.QLayouted.QLayouted
  magneticalc.QtWidgets2.QLayouted.QLayouted.html
  Class
  Class
  PUBLIC
  QLayouted class.
- magneticalc.QtWidgets2.QLayouted.QLayouted.__init__
  magneticalc.QtWidgets2.QLayouted.QLayouted.html#__init__
  Function
  Method
  PUBLIC
  Initializes the QLayouted class. This adds a layout and several related functions like addWidget() to the parent class.
- magneticalc.QtWidgets2.QLayouted.QLayouted._layout
  magneticalc.QtWidgets2.QLayouted.QLayouted.html#_layout
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QtWidgets2.QLayouted.QLayouted.install_layout
  magneticalc.QtWidgets2.QLayouted.QLayouted.html#install_layout
  Function
  Method
  PUBLIC
  Installs this layout in the parent.
- magneticalc.QtWidgets2.QLayouted.QLayouted.addWidget
  magneticalc.QtWidgets2.QLayouted.QLayouted.html#addWidget
  Function
  Method
  PUBLIC
  Adds widget.
- magneticalc.QtWidgets2.QLayouted.QLayouted.addLayout
  magneticalc.QtWidgets2.QLayouted.QLayouted.html#addLayout
  Function
  Method
  PUBLIC
  Adds layout.
- magneticalc.QtWidgets2.QLayouted.QLayouted.addSpacing
  magneticalc.QtWidgets2.QLayouted.QLayouted.html#addSpacing
  Function
  Method
  PUBLIC
  Adds spacing.
- magneticalc.QtWidgets2.QLayouted.QLayouted.addButtons
  magneticalc.QtWidgets2.QLayouted.QLayouted.html#addButtons
  Function
  Method
  PUBLIC
  Adds buttons.
- magneticalc.QtWidgets2.QDialog2.QDialog2
  magneticalc.QtWidgets2.QDialog2.QDialog2.html
  Class
  Class
  PUBLIC
  QDialog2 class.
- magneticalc.QtWidgets2.QDialog2.QDialog2.__init__
  magneticalc.QtWidgets2.QDialog2.QDialog2.html#__init__
  Function
  Method
  PUBLIC
  Initializes QDialog2.
- magneticalc.QtWidgets2.QDialog2.QDialog2.user_accepted
  magneticalc.QtWidgets2.QDialog2.QDialog2.html#user_accepted
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.QtWidgets2.QDialog2.QDialog2.show
  magneticalc.QtWidgets2.QDialog2.QDialog2.html#show
  Function
  Method
  PUBLIC
  Shows this dialog.
- magneticalc.QtWidgets2.QDialog2.QDialog2.showEvent
  magneticalc.QtWidgets2.QDialog2.QDialog2.html#showEvent
  Function
  Method
  PUBLIC
  Gets called when the dialog is opened.
- magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2
  magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2.html
  Class
  Class
  PUBLIC
  QTextBrowser2 class.
- magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2.__init__
  magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2.html#__init__
  Function
  Method
  PUBLIC
  Initializes QTextBrowser2.
- magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2.fit_to_contents
  magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2.html#fit_to_contents
  Function
  Method
  PUBLIC
  Fit to contents.
- magneticalc.Debug.Debug
  magneticalc.Debug.Debug.html
  Class
  Class
  PUBLIC
  Debug class.
- magneticalc.Debug.Debug.EnableInit
  magneticalc.Debug.Debug.html#EnableInit
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Debug.Debug.EnableRefresh
  magneticalc.Debug.Debug.html#EnableRefresh
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Debug.Debug.EnableBlacklist
  magneticalc.Debug.Debug.html#EnableBlacklist
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Debug.Debug.Blacklist
  magneticalc.Debug.Debug.html#Blacklist
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Debug.Debug.__init__
  magneticalc.Debug.Debug.html#__init__
  Function
  Method
  PUBLIC
  Displays a colorful debug message and the current call hierarchy.
- magneticalc.Theme.Theme
  magneticalc.Theme.Theme.html
  Class
  Class
  PUBLIC
  Theme class.
- magneticalc.Theme.Theme.MainColor
  magneticalc.Theme.Theme.html#MainColor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Theme.Theme.LiteColor
  magneticalc.Theme.Theme.html#LiteColor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Theme.Theme.DarkColor
  magneticalc.Theme.Theme.html#DarkColor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Theme.Theme.SuccessColor
  magneticalc.Theme.Theme.html#SuccessColor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Theme.Theme.FailureColor
  magneticalc.Theme.Theme.html#FailureColor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Theme.Theme.QuestionColor
  magneticalc.Theme.Theme.html#QuestionColor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Theme.Theme.DialogTextColor
  magneticalc.Theme.Theme.html#DialogTextColor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Theme.Theme.DefaultFontFace
  magneticalc.Theme.Theme.html#DefaultFontFace
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Version.__VERSION__
  magneticalc.Version.html#__VERSION__
  Attribute
  Constant
  PUBLIC
  Undocumented
- magneticalc.Version.__URL__
  magneticalc.Version.html#__URL__
  Attribute
  Constant
  PUBLIC
  Undocumented
- magneticalc.Version.__PYPI_SIMPLE__URL__
  magneticalc.Version.html#__PYPI_SIMPLE__URL__
  Attribute
  Constant
  PUBLIC
  Undocumented
- magneticalc.Version.Version
  magneticalc.Version.Version.html
  Class
  Class
  PUBLIC
  Version class.
- magneticalc.Version.Version.String
  magneticalc.Version.Version.html#String
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Version.Version.Copyright
  magneticalc.Version.Version.html#Copyright
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Version.Version.License
  magneticalc.Version.Version.html#License
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.About_Dialog.About_Dialog
  magneticalc.About_Dialog.About_Dialog.html
  Class
  Class
  PUBLIC
  About_Dialog class.
- magneticalc.About_Dialog.About_Dialog.DonationURL
  magneticalc.About_Dialog.About_Dialog.html#DonationURL
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.About_Dialog.About_Dialog.HTML
  magneticalc.About_Dialog.About_Dialog.html#HTML
  Attribute
  Constant
  PUBLIC
  Undocumented
- magneticalc.About_Dialog.About_Dialog.__init__
  magneticalc.About_Dialog.About_Dialog.html#__init__
  Function
  Method
  PUBLIC
  Initializes the dialog.
- magneticalc.About_Dialog.About_Dialog.text_browser
  magneticalc.About_Dialog.About_Dialog.html#text_browser
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.About_Dialog.About_Dialog.showEvent
  magneticalc.About_Dialog.About_Dialog.html#showEvent
  Function
  Method
  PUBLIC
  Gets called when the dialog is opened.
- magneticalc.Assert_Dialog.Assert_Dialog
  magneticalc.Assert_Dialog.Assert_Dialog.html
  Class
  Class
  PUBLIC
  Assert_Dialog class.
- magneticalc.Assert_Dialog.Assert_Dialog.__init__
  magneticalc.Assert_Dialog.Assert_Dialog.html#__init__
  Function
  Method
  PUBLIC
  Shows a user dialog if an assertion failed. Intended for beta-testing. This allows the user to either quit or resume (possibly resulting in unstable behaviour). Furthermore, it provides a link for filing an issue on GitHub (partially prefilled).
- magneticalc.Assert_Dialog.Assert_Dialog._dialog
  magneticalc.Assert_Dialog.Assert_Dialog.html#_dialog
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Constants.Constants
  magneticalc.Constants.Constants.html
  Class
  Class
  PUBLIC
  Constants class.
- magneticalc.Constants.Constants.mu_0
  magneticalc.Constants.Constants.html#mu_0
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Types.FIELD_TYPE_A
  magneticalc.Field_Types.html#FIELD_TYPE_A
  Attribute
  Constant
  PUBLIC
  Field type: B-Field.
- magneticalc.Field_Types.FIELD_TYPE_B
  magneticalc.Field_Types.html#FIELD_TYPE_B
  Attribute
  Constant
  PUBLIC
  Map of field types to names.
- magneticalc.Field_Types.Field_Types_Names_Map
  magneticalc.Field_Types.html#Field_Types_Names_Map
  Attribute
  Variable
  PUBLIC
  Map of field types to abbreviations.
- magneticalc.Field_Types.Field_Types_Abbreviations_Map
  magneticalc.Field_Types.html#Field_Types_Abbreviations_Map
  Attribute
  Variable
  PUBLIC
  Default field type.
- magneticalc.Field_Types.field_type_safe
  magneticalc.Field_Types.html#field_type_safe
  Function
  Function
  PUBLIC
  A valid field type is passed through, but an invalid field type converts to the default type.
- magneticalc.Field_Types.field_name_to_type
  magneticalc.Field_Types.html#field_name_to_type
  Function
  Function
  PUBLIC
  Converts a field name to a field type.
- magneticalc.Backend_CUDA.Backend_CUDA
  magneticalc.Backend_CUDA.Backend_CUDA.html
  Class
  Class
  PUBLIC
  Implements the Biot-Savart law for calculating the magnetic flux density (B-field) and vector potential (A-field). Backend: JIT + CUDA.
- magneticalc.Backend_CUDA.Backend_CUDA.__init__
  magneticalc.Backend_CUDA.Backend_CUDA.html#__init__
  Function
  Method
  PUBLIC
  Initializes the class attributes.
- magneticalc.Backend_CUDA.Backend_CUDA._field_type
  magneticalc.Backend_CUDA.Backend_CUDA.html#_field_type
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_CUDA.Backend_CUDA._distance_limit
  magneticalc.Backend_CUDA.Backend_CUDA.html#_distance_limit
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_CUDA.Backend_CUDA._length_scale
  magneticalc.Backend_CUDA.Backend_CUDA.html#_length_scale
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_CUDA.Backend_CUDA._dc
  magneticalc.Backend_CUDA.Backend_CUDA.html#_dc
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_CUDA.Backend_CUDA._current_elements
  magneticalc.Backend_CUDA.Backend_CUDA.html#_current_elements
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_CUDA.Backend_CUDA._sampling_volume_points
  magneticalc.Backend_CUDA.Backend_CUDA.html#_sampling_volume_points
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_CUDA.Backend_CUDA._sampling_volume_permeabilities
  magneticalc.Backend_CUDA.Backend_CUDA.html#_sampling_volume_permeabilities
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_CUDA.Backend_CUDA._progress_callback
  magneticalc.Backend_CUDA.Backend_CUDA.html#_progress_callback
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_CUDA.Backend_CUDA.worker
  magneticalc.Backend_CUDA.Backend_CUDA.html#worker
  Function
  Static Method
  PUBLIC
  Applies the Biot-Savart law for calculating the magnetic flux density (B-field) or vector potential (A-field) for all sampling volume points.
- magneticalc.Backend_CUDA.Backend_CUDA.get_result
  magneticalc.Backend_CUDA.Backend_CUDA.html#get_result
  Function
  Method
  PUBLIC
  Calculates the field at every point of the sampling volume.
- magneticalc.Backend_Types.get_jit_enabled
  magneticalc.Backend_Types.html#get_jit_enabled
  Function
  Function
  PUBLIC
  Checks if JIT is enabled (or at least not explicitly disabled).
- magneticalc.Backend_Types.get_cuda_available
  magneticalc.Backend_Types.html#get_cuda_available
  Function
  Function
  PUBLIC
  Checks if CUDA is available
- magneticalc.Backend_Types.BACKEND_TYPE_JIT
  magneticalc.Backend_Types.html#BACKEND_TYPE_JIT
  Attribute
  Constant
  PUBLIC
  Backend type: CUDA.
- magneticalc.Backend_Types.BACKEND_TYPE_CUDA
  magneticalc.Backend_Types.html#BACKEND_TYPE_CUDA
  Attribute
  Constant
  PUBLIC
  Map of backend types to their availability.
- magneticalc.Backend_Types.Backend_Types_Available
  magneticalc.Backend_Types.html#Backend_Types_Available
  Attribute
  Variable
  PUBLIC
  Map of backend types to names.
- magneticalc.Backend_Types.Backend_Types_Names_Map
  magneticalc.Backend_Types.html#Backend_Types_Names_Map
  Attribute
  Variable
  PUBLIC
  Default backend type.
- magneticalc.Backend_Types.backend_type_safe
  magneticalc.Backend_Types.html#backend_type_safe
  Function
  Function
  PUBLIC
  A valid backend type is passed through, but an invalid backend type converts to the default type.
- magneticalc.Backend_Types.backend_type_to_name
  magneticalc.Backend_Types.html#backend_type_to_name
  Function
  Function
  PUBLIC
  Converts a backend type to a backend name.
- magneticalc.ConditionalDecorator.ConditionalDecorator
  magneticalc.ConditionalDecorator.ConditionalDecorator.html
  Class
  Class
  PUBLIC
  ConditionalDecorator class.
- magneticalc.ConditionalDecorator.ConditionalDecorator.__init__
  magneticalc.ConditionalDecorator.ConditionalDecorator.html#__init__
  Function
  Method
  PUBLIC
  Initializes a conditional decorator.
- magneticalc.ConditionalDecorator.ConditionalDecorator.condition
  magneticalc.ConditionalDecorator.ConditionalDecorator.html#condition
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.ConditionalDecorator.ConditionalDecorator.decorating_func
  magneticalc.ConditionalDecorator.ConditionalDecorator.html#decorating_func
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.ConditionalDecorator.ConditionalDecorator.decorating_args
  magneticalc.ConditionalDecorator.ConditionalDecorator.html#decorating_args
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.ConditionalDecorator.ConditionalDecorator.__call__
  magneticalc.ConditionalDecorator.ConditionalDecorator.html#__call__
  Function
  Method
  PUBLIC
  Gets called when a function is to be decorated.
- magneticalc.Backend_JIT.Backend_JIT
  magneticalc.Backend_JIT.Backend_JIT.html
  Class
  Class
  PUBLIC
  Implements the Biot-Savart law for calculating the magnetic flux density (B-field) and vector potential (A-field). Backend: JIT.
- magneticalc.Backend_JIT.Backend_JIT.__init__
  magneticalc.Backend_JIT.Backend_JIT.html#__init__
  Function
  Method
  PUBLIC
  Initializes the class attributes.
- magneticalc.Backend_JIT.Backend_JIT._field_type
  magneticalc.Backend_JIT.Backend_JIT.html#_field_type
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_JIT.Backend_JIT._distance_limit
  magneticalc.Backend_JIT.Backend_JIT.html#_distance_limit
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_JIT.Backend_JIT._length_scale
  magneticalc.Backend_JIT.Backend_JIT.html#_length_scale
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_JIT.Backend_JIT._dc
  magneticalc.Backend_JIT.Backend_JIT.html#_dc
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_JIT.Backend_JIT._current_elements
  magneticalc.Backend_JIT.Backend_JIT.html#_current_elements
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_JIT.Backend_JIT._sampling_volume_points
  magneticalc.Backend_JIT.Backend_JIT.html#_sampling_volume_points
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_JIT.Backend_JIT._sampling_volume_permeabilities
  magneticalc.Backend_JIT.Backend_JIT.html#_sampling_volume_permeabilities
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_JIT.Backend_JIT._progress_callback
  magneticalc.Backend_JIT.Backend_JIT.html#_progress_callback
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Backend_JIT.Backend_JIT.worker
  magneticalc.Backend_JIT.Backend_JIT.html#worker
  Function
  Static Method
  PUBLIC
  Applies the Biot-Savart law for calculating the magnetic flux density (B-field) or vector potential (A-field) for a single sampling volume point.
- magneticalc.Backend_JIT.Backend_JIT.get_result
  magneticalc.Backend_JIT.Backend_JIT.html#get_result
  Function
  Method
  PUBLIC
  Calculates the field at every point of the sampling volume.
- magneticalc.ModelAccess.ModelAccess
  magneticalc.ModelAccess.ModelAccess.html
  Class
  Class
  PUBLIC
  Model access class.
- magneticalc.ModelAccess.ModelAccess.DebugValidity
  magneticalc.ModelAccess.ModelAccess.html#DebugValidity
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.ModelAccess.ModelAccess.__init__
  magneticalc.ModelAccess.ModelAccess.html#__init__
  Function
  Method
  PUBLIC
  Initializes model access.
- magneticalc.ModelAccess.ModelAccess.gui
  magneticalc.ModelAccess.ModelAccess.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.ModelAccess.ModelAccess._recalculate
  magneticalc.ModelAccess.ModelAccess.html#_recalculate
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.ModelAccess.ModelAccess.__enter__
  magneticalc.ModelAccess.ModelAccess.html#__enter__
  Function
  Method
  PUBLIC
  Entering the context kills possibly running calculation if recalculation is enabled.
- magneticalc.ModelAccess.ModelAccess.__exit__
  magneticalc.ModelAccess.ModelAccess.html#__exit__
  Function
  Method
  PUBLIC
  Leaving the context starts recalculation if enabled; otherwise, just redraw.
- magneticalc.CalculationThread.CalculationThread
  magneticalc.CalculationThread.CalculationThread.html
  Class
  Class
  PUBLIC
  CalculationThread class. The calculation thread implements an offloaded pipeline of subsequent calculation subtasks. The pipeline may be interrupted at (almost) any time, thereby exiting this thread.
- magneticalc.CalculationThread.CalculationThread._progress_update
  magneticalc.CalculationThread.CalculationThread.html#_progress_update
  Attribute
  Class Variable
  PRIVATE
  Undocumented
- magneticalc.CalculationThread.CalculationThread._wire_valid
  magneticalc.CalculationThread.CalculationThread.html#_wire_valid
  Attribute
  Class Variable
  PRIVATE
  Undocumented
- magneticalc.CalculationThread.CalculationThread._sampling_volume_valid
  magneticalc.CalculationThread.CalculationThread.html#_sampling_volume_valid
  Attribute
  Class Variable
  PRIVATE
  Undocumented
- magneticalc.CalculationThread.CalculationThread._field_valid
  magneticalc.CalculationThread.CalculationThread.html#_field_valid
  Attribute
  Class Variable
  PRIVATE
  Undocumented
- magneticalc.CalculationThread.CalculationThread._metric_valid
  magneticalc.CalculationThread.CalculationThread.html#_metric_valid
  Attribute
  Class Variable
  PRIVATE
  Undocumented
- magneticalc.CalculationThread.CalculationThread._parameters_valid
  magneticalc.CalculationThread.CalculationThread.html#_parameters_valid
  Attribute
  Class Variable
  PRIVATE
  Undocumented
- magneticalc.CalculationThread.CalculationThread.__init__
  magneticalc.CalculationThread.CalculationThread.html#__init__
  Function
  Method
  PUBLIC
  Initializes calculation thread.
- magneticalc.CalculationThread.CalculationThread.gui
  magneticalc.CalculationThread.CalculationThread.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.CalculationThread.CalculationThread.disconnect_signals
  magneticalc.CalculationThread.CalculationThread.html#disconnect_signals
  Function
  Method
  PUBLIC
  Disconnects all valid state signals
- magneticalc.CalculationThread.CalculationThread.run
  magneticalc.CalculationThread.CalculationThread.html#run
  Function
  Method
  PUBLIC
  Thread main function.
- magneticalc.CalculationThread.CalculationThread._on_finished
  magneticalc.CalculationThread.CalculationThread.html#_on_finished
  Function
  Method
  PRIVATE
  Signals that the calculation finished.
- magneticalc.QtWidgets2.QLabel2.QLabel2
  magneticalc.QtWidgets2.QLabel2.QLabel2.html
  Class
  Class
  PUBLIC
  QLabel2 class.
- magneticalc.QtWidgets2.QLabel2.QLabel2.DebugLabels
  magneticalc.QtWidgets2.QLabel2.QLabel2.html#DebugLabels
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.QtWidgets2.QLabel2.QLabel2.__init__
  magneticalc.QtWidgets2.QLabel2.QLabel2.html#__init__
  Function
  Method
  PUBLIC
  Initializes a QLabel.
- magneticalc.QtWidgets2.QLabel2.QLabel2.set
  magneticalc.QtWidgets2.QLabel2.QLabel2.html#set
  Function
  Method
  PUBLIC
  Sets the label properties.
- magneticalc.QtWidgets2.QIconLabel.QIconLabel
  magneticalc.QtWidgets2.QIconLabel.QIconLabel.html
  Class
  Class
  PUBLIC
  QIconLabel class.
- magneticalc.QtWidgets2.QIconLabel.QIconLabel.HorizontalSpacing
  magneticalc.QtWidgets2.QIconLabel.QIconLabel.html#HorizontalSpacing
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.QtWidgets2.QIconLabel.QIconLabel.__init__
  magneticalc.QtWidgets2.QIconLabel.QIconLabel.html#__init__
  Function
  Method
  PUBLIC
  Initializes the icon label.
- magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog
  magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.html
  Class
  Class
  PUBLIC
  CheckForUpdates_Dialog class.
- magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.__init__
  magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.html#__init__
  Function
  Method
  PUBLIC
  Initializes the dialog.
- magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.check_for_updates
  magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.html#check_for_updates
  Function
  Method
  PUBLIC
  Checks for updates.
- magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.remote_contents
  magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.html#remote_contents
  Function
  Static Method
  PUBLIC
  Gets the contents of a remote file.
- magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.parse_contents
  magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.html#parse_contents
  Function
  Static Method
  PUBLIC
  Extracts and parses the version number from the raw Version.py contents.
- magneticalc.Comparison_Types.COMPARISON_TYPE_IN_RANGE
  magneticalc.Comparison_Types.html#COMPARISON_TYPE_IN_RANGE
  Attribute
  Constant
  PUBLIC
  Comparison type: Not In Range.
- magneticalc.Comparison_Types.COMPARISON_TYPE_NOT_IN_RANGE
  magneticalc.Comparison_Types.html#COMPARISON_TYPE_NOT_IN_RANGE
  Attribute
  Constant
  PUBLIC
  Map of comparison types to names.
- magneticalc.Comparison_Types.Comparison_Types_Names_Map
  magneticalc.Comparison_Types.html#Comparison_Types_Names_Map
  Attribute
  Variable
  PUBLIC
  Default comparison type.
- magneticalc.Comparison_Types.comparison_type_safe
  magneticalc.Comparison_Types.html#comparison_type_safe
  Function
  Function
  PUBLIC
  A valid comparison type is passed through, but an invalid comparison type converts to the default type.
- magneticalc.Comparison_Types.comparison_type_to_name
  magneticalc.Comparison_Types.html#comparison_type_to_name
  Function
  Function
  PUBLIC
  Converts a comparison type to a comparison name.
- magneticalc.Comparison_Types.comparison_name_to_type
  magneticalc.Comparison_Types.html#comparison_name_to_type
  Function
  Function
  PUBLIC
  Converts a comparison name to a comparison type.
- magneticalc.Format.Format
  magneticalc.Format.Format.html
  Class
  Class
  PUBLIC
  Format class.
- magneticalc.Format.Format.FloatPrecision
  magneticalc.Format.Format.html#FloatPrecision
  Attribute
  Class Variable
  PUBLIC
  Coordinate precision.
- magneticalc.Format.Format.CoordinatePrecision
  magneticalc.Format.Format.html#CoordinatePrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Format.Format.absolute_filename
  magneticalc.Format.Format.html#absolute_filename
  Function
  Static Method
  PUBLIC
  Converts a filename to an absolute filename.
- magneticalc.Format.Format.filename_uri
  magneticalc.Format.Format.html#filename_uri
  Function
  Static Method
  PUBLIC
  Converts a filename to a filename URI.
- magneticalc.Format.Format.float_to_str
  magneticalc.Format.Format.html#float_to_str
  Function
  Static Method
  PUBLIC
  Converts a float value to string.
- magneticalc.Format.Format.point_to_str
  magneticalc.Format.Format.html#point_to_str
  Function
  Static Method
  PUBLIC
  Converts a single 3D point to string.
- magneticalc.Format.Format.points_to_str
  magneticalc.Format.Format.html#points_to_str
  Function
  Static Method
  PUBLIC
  Converts list of 3D points to string.
- magneticalc.Format.Format.str_to_point
  magneticalc.Format.Format.html#str_to_point
  Function
  Static Method
  PUBLIC
  Converts string to single 3D point.
- magneticalc.Format.Format.str_to_points
  magneticalc.Format.Format.html#str_to_points
  Function
  Static Method
  PUBLIC
  Converts string to list of 3D points.
- magneticalc.Config.Config
  magneticalc.Config.Config.html
  Class
  Class
  PUBLIC
  Config class.
- magneticalc.Config.Config.DebugAccess
  magneticalc.Config.Config.html#DebugAccess
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Config.Config.__init__
  magneticalc.Config.Config.html#__init__
  Function
  Method
  PUBLIC
  Initializes the configuration.
- magneticalc.Config.Config._parser
  magneticalc.Config.Config.html#_parser
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Config.Config.filename
  magneticalc.Config.Config.html#filename
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Config.Config.synced
  magneticalc.Config.Config.html#synced
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Config.Config.on_changed
  magneticalc.Config.Config.html#on_changed
  Function
  Method
  PUBLIC
  Gets called when the configuration was loaded, saved or changed.
- magneticalc.Config.Config.load
  magneticalc.Config.Config.html#load
  Function
  Method
  PUBLIC
  Loads the default configuration.
- magneticalc.Config.Config.load_file
  magneticalc.Config.Config.html#load_file
  Function
  Method
  PUBLIC
  Loads the configuration from file.
- magneticalc.Config.Config.save_file
  magneticalc.Config.Config.html#save_file
  Function
  Method
  PUBLIC
  Saves the configuration to file.
- magneticalc.Config.Config.cleanup
  magneticalc.Config.Config.html#cleanup
  Function
  Method
  PUBLIC
  Perform clean-up.
- magneticalc.Config.Config.remove_key
  magneticalc.Config.Config.html#remove_key
  Function
  Method
  PUBLIC
  Removes a key from the configuration.
- magneticalc.Config.Config.set_get_str
  magneticalc.Config.Config.html#set_get_str
  Function
  Method
  PUBLIC
  If value is not None, writes and returns key-value; otherwise (if value is None), reads and returns key-value.
- magneticalc.Config.Config.set_str
  magneticalc.Config.Config.html#set_str
  Function
  Method
  PUBLIC
  Writes a configuration value.
- magneticalc.Config.Config.get_str
  magneticalc.Config.Config.html#get_str
  Function
  Method
  PUBLIC
  Reads a configuration value.
- magneticalc.Config.Config.set_get_bool
  magneticalc.Config.Config.html#set_get_bool
  Function
  Method
  PUBLIC
  If value is not None, writes and returns key-value; otherwise (if value is None), reads and returns key-value.
- magneticalc.Config.Config.set_bool
  magneticalc.Config.Config.html#set_bool
  Function
  Method
  PUBLIC
  Sets boolean value, convert to string.
- magneticalc.Config.Config.get_bool
  magneticalc.Config.Config.html#get_bool
  Function
  Method
  PUBLIC
  Gets boolean value, convert from string.
- magneticalc.Config.Config.set_get_int
  magneticalc.Config.Config.html#set_get_int
  Function
  Method
  PUBLIC
  If value is not None, writes and returns key-value; otherwise (if value is None), reads and returns key-value.
- magneticalc.Config.Config.set_int
  magneticalc.Config.Config.html#set_int
  Function
  Method
  PUBLIC
  Sets integer value, convert to string.
- magneticalc.Config.Config.get_int
  magneticalc.Config.Config.html#get_int
  Function
  Method
  PUBLIC
  Gets integer value, convert from string.
- magneticalc.Config.Config.set_get_float
  magneticalc.Config.Config.html#set_get_float
  Function
  Method
  PUBLIC
  If value is not None, writes and returns key-value; otherwise (if value is None), reads and returns key-value.
- magneticalc.Config.Config.set_float
  magneticalc.Config.Config.html#set_float
  Function
  Method
  PUBLIC
  Sets float value, convert to string.
- magneticalc.Config.Config.get_float
  magneticalc.Config.Config.html#get_float
  Function
  Method
  PUBLIC
  Gets float value, convert from string.
- magneticalc.Config.Config.set_get_point
  magneticalc.Config.Config.html#set_get_point
  Function
  Method
  PUBLIC
  If value is not None, writes and returns key-value; otherwise (if value is None), reads and returns key-value.
- magneticalc.Config.Config.set_point
  magneticalc.Config.Config.html#set_point
  Function
  Method
  PUBLIC
  Sets a single 3D point, convert to string.
- magneticalc.Config.Config.get_point
  magneticalc.Config.Config.html#get_point
  Function
  Method
  PUBLIC
  Gets a single 3D point, convert from string.
- magneticalc.Config.Config.set_get_points
  magneticalc.Config.Config.html#set_get_points
  Function
  Method
  PUBLIC
  If value is not None, writes and returns key-value; otherwise (if value is None), reads and returns key-value.
- magneticalc.Config.Config.set_points
  magneticalc.Config.Config.html#set_points
  Function
  Method
  PUBLIC
  Sets list of 3D points, convert to string.
- magneticalc.Config.Config.get_points
  magneticalc.Config.Config.html#get_points
  Function
  Method
  PUBLIC
  Gets list of 3D points, convert from string.
- magneticalc.Config.Config.set_get_dict
  magneticalc.Config.Config.html#set_get_dict
  Function
  Method
  PUBLIC
  If "values" is None, reads and returns all key-values in "types". Note: The actual keys saved in the configuration file are prefixed with "prefix", and suffixed with "suffix".
- magneticalc.Config.Config.get_generic
  magneticalc.Config.Config.html#get_generic
  Function
  Method
  PUBLIC
  Gets some "_key"-"_value" of data type "_type".
- magneticalc.Config.Config.set_generic
  magneticalc.Config.Config.html#set_generic
  Function
  Method
  PUBLIC
  Sets some "_key"-"_value" of data type "_type".
- magneticalc.Config_Group.Config_Collection
  magneticalc.Config_Group.Config_Collection.html
  Class
  Class
  PUBLIC
  Config_Collection class.
- magneticalc.Config_Group.Config_Collection.__init__
  magneticalc.Config_Group.Config_Collection.html#__init__
  Function
  Method
  PUBLIC
  Initializes a config collection: A list of groups (dictionaries).
- magneticalc.Config_Group.Config_Collection.gui
  magneticalc.Config_Group.Config_Collection.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Config_Group.Config_Collection.prefix
  magneticalc.Config_Group.Config_Collection.html#prefix
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Config_Group.Config_Collection.types
  magneticalc.Config_Group.Config_Collection.html#types
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Config_Group.Config_Collection.first_without_suffix
  magneticalc.Config_Group.Config_Collection.html#first_without_suffix
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Config_Group.Config_Collection._get_suffix
  magneticalc.Config_Group.Config_Collection.html#_get_suffix
  Function
  Method
  PRIVATE
  Gets the suffix for a given group index.
- magneticalc.Config_Group.Config_Collection.get_count
  magneticalc.Config_Group.Config_Collection.html#get_count
  Function
  Method
  PUBLIC
  Gets the number of groups in the collection.
- magneticalc.Config_Group.Config_Collection.get_group
  magneticalc.Config_Group.Config_Collection.html#get_group
  Function
  Method
  PUBLIC
  Gets a group from the collection.
- magneticalc.Config_Group.Config_Collection.get_all_groups
  magneticalc.Config_Group.Config_Collection.html#get_all_groups
  Function
  Method
  PUBLIC
  Gets every group in the collection.
- magneticalc.Config_Group.Config_Collection.add_group
  magneticalc.Config_Group.Config_Collection.html#add_group
  Function
  Method
  PUBLIC
  Appends a group to the collection.
- magneticalc.Config_Group.Config_Collection.del_group
  magneticalc.Config_Group.Config_Collection.html#del_group
  Function
  Method
  PUBLIC
  Deletes a group from the collection.
- magneticalc.Config_Group.Config_Collection.set
  magneticalc.Config_Group.Config_Collection.html#set
  Function
  Method
  PUBLIC
  Sets a value for some key in a group of the collection.
- magneticalc.Norm_Types.NORM_TYPE_X
  magneticalc.Norm_Types.html#NORM_TYPE_X
  Attribute
  Constant
  PUBLIC
  Norm type: Y.
- magneticalc.Norm_Types.NORM_TYPE_Y
  magneticalc.Norm_Types.html#NORM_TYPE_Y
  Attribute
  Constant
  PUBLIC
  Norm type: Z.
- magneticalc.Norm_Types.NORM_TYPE_Z
  magneticalc.Norm_Types.html#NORM_TYPE_Z
  Attribute
  Constant
  PUBLIC
  Norm type: Radius.
- magneticalc.Norm_Types.NORM_TYPE_RADIUS
  magneticalc.Norm_Types.html#NORM_TYPE_RADIUS
  Attribute
  Constant
  PUBLIC
  Norm type: Radius X.
- magneticalc.Norm_Types.NORM_TYPE_RADIUS_X
  magneticalc.Norm_Types.html#NORM_TYPE_RADIUS_X
  Attribute
  Constant
  PUBLIC
  Norm type: Radius Y.
- magneticalc.Norm_Types.NORM_TYPE_RADIUS_Y
  magneticalc.Norm_Types.html#NORM_TYPE_RADIUS_Y
  Attribute
  Constant
  PUBLIC
  Norm type: Radius Z.
- magneticalc.Norm_Types.NORM_TYPE_RADIUS_Z
  magneticalc.Norm_Types.html#NORM_TYPE_RADIUS_Z
  Attribute
  Constant
  PUBLIC
  Norm type: Radius XY.
- magneticalc.Norm_Types.NORM_TYPE_RADIUS_XY
  magneticalc.Norm_Types.html#NORM_TYPE_RADIUS_XY
  Attribute
  Constant
  PUBLIC
  Norm type: Radius XZ.
- magneticalc.Norm_Types.NORM_TYPE_RADIUS_XZ
  magneticalc.Norm_Types.html#NORM_TYPE_RADIUS_XZ
  Attribute
  Constant
  PUBLIC
  Norm type: Radius YZ.
- magneticalc.Norm_Types.NORM_TYPE_RADIUS_YZ
  magneticalc.Norm_Types.html#NORM_TYPE_RADIUS_YZ
  Attribute
  Constant
  PUBLIC
  Norm type: Angle XY.
- magneticalc.Norm_Types.NORM_TYPE_ANGLE_XY
  magneticalc.Norm_Types.html#NORM_TYPE_ANGLE_XY
  Attribute
  Constant
  PUBLIC
  Norm type: Angle XZ.
- magneticalc.Norm_Types.NORM_TYPE_ANGLE_XZ
  magneticalc.Norm_Types.html#NORM_TYPE_ANGLE_XZ
  Attribute
  Constant
  PUBLIC
  Norm type: Angle YZ.
- magneticalc.Norm_Types.NORM_TYPE_ANGLE_YZ
  magneticalc.Norm_Types.html#NORM_TYPE_ANGLE_YZ
  Attribute
  Constant
  PUBLIC
  Norm type: Divergence.
- magneticalc.Norm_Types.NORM_TYPE_DIVERGENCE
  magneticalc.Norm_Types.html#NORM_TYPE_DIVERGENCE
  Attribute
  Constant
  PUBLIC
  Map of norm types to names.
- magneticalc.Norm_Types.Norm_Types_Names_Map
  magneticalc.Norm_Types.html#Norm_Types_Names_Map
  Attribute
  Variable
  PUBLIC
  Default norm type.
- magneticalc.Norm_Types.norm_type_safe
  magneticalc.Norm_Types.html#norm_type_safe
  Function
  Function
  PUBLIC
  A valid norm type is passed through, but an invalid norm type converts to the default type.
- magneticalc.Norm_Types.norm_type_to_name
  magneticalc.Norm_Types.html#norm_type_to_name
  Function
  Function
  PUBLIC
  Converts a norm type to a norm name.
- magneticalc.Norm_Types.norm_name_to_type
  magneticalc.Norm_Types.html#norm_name_to_type
  Function
  Function
  PUBLIC
  Converts a norm name to a norm type.
- magneticalc.Validatable.Validatable
  magneticalc.Validatable.Validatable.html
  Class
  Class
  PUBLIC
  Validatable class.
- magneticalc.Validatable.Validatable.__init__
  magneticalc.Validatable.Validatable.html#__init__
  Function
  Method
  PUBLIC
  Initializes a validatable object.
- magneticalc.Validatable.Validatable._valid
  magneticalc.Validatable.Validatable.html#_valid
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Validatable.Validatable.valid
  magneticalc.Validatable.Validatable.html#valid
  Attribute
  Property
  PUBLIC
  True if valid, False if invalid
- magneticalc.Validatable.Validatable.valid.setter
  magneticalc.Validatable.Validatable.html#valid.setter
  Function
  Method
  PUBLIC
  No summary
- magneticalc.Validatable.require_valid
  magneticalc.Validatable.html#require_valid
  Function
  Function
  PUBLIC
  Decorator that requires a validatable object to be valid before calling a function.
- magneticalc.Validatable.validator
  magneticalc.Validatable.html#validator
  Function
  Function
  PUBLIC
  Decorator that invalidates a validatable object and then validates it based on the result of calling a function.
- magneticalc.Metric.metric_norm
  magneticalc.Metric.html#metric_norm
  Function
  Function
  PUBLIC
  Calculates the selected norm of some vector.
- magneticalc.Metric.metric_divergence
  magneticalc.Metric.html#metric_divergence
  Function
  Function
  PUBLIC
  Calculates the divergence of a sampling volume neighborhood.
- magneticalc.Metric.color_map_divergent
  magneticalc.Metric.html#color_map_divergent
  Function
  Function
  PUBLIC
  Maps normalized value to color, divergent.
- magneticalc.Metric.color_map_cyclic
  magneticalc.Metric.html#color_map_cyclic
  Function
  Function
  PUBLIC
  Maps normalized value to color, cyclic.
- magneticalc.Metric.Metric
  magneticalc.Metric.Metric.html
  Class
  Class
  PUBLIC
  Provides different metrics, used for mapping some field vector properties to some color and alpha range.
- magneticalc.Metric.Metric.LengthScale
  magneticalc.Metric.Metric.html#LengthScale
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric.Metric.LogNormMin
  magneticalc.Metric.Metric.html#LogNormMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric.Metric.__init__
  magneticalc.Metric.Metric.html#__init__
  Function
  Method
  PUBLIC
  Initializes an empty metric.
- magneticalc.Metric.Metric.color_preset
  magneticalc.Metric.Metric.html#color_preset
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric.Metric.alpha_preset
  magneticalc.Metric.Metric.html#alpha_preset
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric.Metric._colors
  magneticalc.Metric.Metric.html#_colors
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Metric.Metric._limits
  magneticalc.Metric.Metric.html#_limits
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Metric.Metric.set
  magneticalc.Metric.Metric.html#set
  Function
  Method
  PUBLIC
  Sets the parameters.
- magneticalc.Metric.Metric._norm_worker
  magneticalc.Metric.Metric.html#_norm_worker
  Function
  Static Method
  PRIVATE
  Calculates the norm values of a list of vectors.
- magneticalc.Metric.Metric._divergence_worker
  magneticalc.Metric.Metric.html#_divergence_worker
  Function
  Static Method
  PRIVATE
  Calculates the divergence values of a list of vectors.
- magneticalc.Metric.Metric._normalize_worker
  magneticalc.Metric.Metric.html#_normalize_worker
  Function
  Static Method
  PRIVATE
  Normalizes color and alpha norm values, populates final color values.
- magneticalc.Metric.Metric.recalculate
  magneticalc.Metric.Metric.html#recalculate
  Function
  Method
  PUBLIC
  Recalculates color and alpha values for field.
- magneticalc.Metric.Metric.colors
  magneticalc.Metric.Metric.html#colors
  Attribute
  Property
  PUBLIC
  Returns calculated colors.
- magneticalc.Metric.Metric.limits
  magneticalc.Metric.Metric.html#limits
  Attribute
  Property
  PUBLIC
  Returns calculated limits.
- magneticalc.Metric.Metric.boost_colors
  magneticalc.Metric.Metric.html#boost_colors
  Function
  Static Method
  PUBLIC
  "Boosts" an array of color values.
- magneticalc.Constraint.Constraint
  magneticalc.Constraint.Constraint.html
  Class
  Class
  PUBLIC
  Constraint class.
- magneticalc.Constraint.Constraint.Norm_Types_Supported
  magneticalc.Constraint.Constraint.html#Norm_Types_Supported
  Attribute
  Class Variable
  PUBLIC
  Supported norm types using minimum and maximum angles in degrees.
- magneticalc.Constraint.Constraint.Norm_Types_Supported_Degrees
  magneticalc.Constraint.Constraint.html#Norm_Types_Supported_Degrees
  Attribute
  Class Variable
  PUBLIC
  Supported comparison types.
- magneticalc.Constraint.Constraint.Comparison_Types_Supported
  magneticalc.Constraint.Constraint.html#Comparison_Types_Supported
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Constraint.Constraint.__init__
  magneticalc.Constraint.Constraint.html#__init__
  Function
  Method
  PUBLIC
  Initializes the constraint.
- magneticalc.Constraint.Constraint._norm_type
  magneticalc.Constraint.Constraint.html#_norm_type
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Constraint.Constraint._comparison_type
  magneticalc.Constraint.Constraint.html#_comparison_type
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Constraint.Constraint._min
  magneticalc.Constraint.Constraint.html#_min
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Constraint.Constraint._max
  magneticalc.Constraint.Constraint.html#_max
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Constraint.Constraint.permeability
  magneticalc.Constraint.Constraint.html#permeability
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Constraint.Constraint.evaluate
  magneticalc.Constraint.Constraint.html#evaluate
  Function
  Method
  PUBLIC
  Evaluate this constraint at some point.
- magneticalc.QtWidgets2.QPushButton2.QPushButton2
  magneticalc.QtWidgets2.QPushButton2.QPushButton2.html
  Class
  Class
  PUBLIC
  QPushButton2 class.
- magneticalc.QtWidgets2.QPushButton2.QPushButton2.__init__
  magneticalc.QtWidgets2.QPushButton2.QPushButton2.html#__init__
  Function
  Method
  PUBLIC
  Initializes a QPushButton.
- magneticalc.QTableView2.TableModel
  magneticalc.QTableView2.TableModel.html
  Class
  Class
  PUBLIC
  TableModel class.
- magneticalc.QTableView2.TableModel.__init__
  magneticalc.QTableView2.TableModel.html#__init__
  Function
  Method
  PUBLIC
  Initializes a table model.
- magneticalc.QTableView2.TableModel._data
  magneticalc.QTableView2.TableModel.html#_data
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.TableModel._row_keys
  magneticalc.QTableView2.TableModel.html#_row_keys
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.TableModel._col_keys
  magneticalc.QTableView2.TableModel.html#_col_keys
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.TableModel._col_is_widget
  magneticalc.QTableView2.TableModel.html#_col_is_widget
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.TableModel.is_widget
  magneticalc.QTableView2.TableModel.html#is_widget
  Function
  Method
  PUBLIC
  Checks if the cell is a widget button.
- magneticalc.QTableView2.TableModel.rowCount
  magneticalc.QTableView2.TableModel.html#rowCount
  Function
  Method
  PUBLIC
  Gets the number of rows.
- magneticalc.QTableView2.TableModel.columnCount
  magneticalc.QTableView2.TableModel.html#columnCount
  Function
  Method
  PUBLIC
  Gets the number of columns. Note: Enabling allow_delete adds an extra column for the row delete buttons.
- magneticalc.QTableView2.TableModel.setData
  magneticalc.QTableView2.TableModel.html#setData
  Function
  Method
  PUBLIC
  Sets a cell value.
- magneticalc.QTableView2.TableModel.data
  magneticalc.QTableView2.TableModel.html#data
  Function
  Method
  PUBLIC
  Gets a cell value.
- magneticalc.QTableView2.TableModel.flags
  magneticalc.QTableView2.TableModel.html#flags
  Function
  Method
  PUBLIC
  Gets the flags for a cell.
- magneticalc.QTableView2.TableModel.headerData
  magneticalc.QTableView2.TableModel.html#headerData
  Function
  Method
  PUBLIC
  Sets the header data.
- magneticalc.QTableView2.QTableView2
  magneticalc.QTableView2.QTableView2.html
  Class
  Class
  PUBLIC
  QTableView2 class.
- magneticalc.QTableView2.QTableView2.__init__
  magneticalc.QTableView2.QTableView2.html#__init__
  Function
  Method
  PUBLIC
  Initializes a table.
- magneticalc.QTableView2.QTableView2.gui
  magneticalc.QTableView2.QTableView2.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.QTableView2.QTableView2._allow_delete
  magneticalc.QTableView2.QTableView2.html#_allow_delete
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2._row_count_minimum
  magneticalc.QTableView2.QTableView2.html#_row_count_minimum
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2._row_prefix
  magneticalc.QTableView2.QTableView2.html#_row_prefix
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2._col_keys
  magneticalc.QTableView2.QTableView2.html#_col_keys
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2._col_types
  magneticalc.QTableView2.QTableView2.html#_col_types
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2._col_options
  magneticalc.QTableView2.QTableView2.html#_col_options
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2._on_cell_edited
  magneticalc.QTableView2.QTableView2.html#_on_cell_edited
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2._on_selection_changed
  magneticalc.QTableView2.QTableView2.html#_on_selection_changed
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2._on_row_deleted
  magneticalc.QTableView2.QTableView2.html#_on_row_deleted
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QTableView2.QTableView2.set_style
  magneticalc.QTableView2.QTableView2.html#set_style
  Function
  Method
  PUBLIC
  Sets this widget's style.
- magneticalc.QTableView2.QTableView2.set_data
  magneticalc.QTableView2.QTableView2.html#set_data
  Function
  Method
  PUBLIC
  Sets the table contents.
- magneticalc.QTableView2.QTableView2.on_data_changed
  magneticalc.QTableView2.QTableView2.html#on_data_changed
  Function
  Method
  PUBLIC
  Gets called when the data in a selection changed. Note: Always assuming only a single cell is selected.
- magneticalc.QTableView2.QTableView2.on_combobox_cell_edited
  magneticalc.QTableView2.QTableView2.html#on_combobox_cell_edited
  Function
  Method
  PUBLIC
  Gets called when a combobox cell has been edited.
- magneticalc.QTableView2.QTableView2.on_row_deleted
  magneticalc.QTableView2.QTableView2.html#on_row_deleted
  Function
  Method
  PUBLIC
  Gets called when a row was deleted.
- magneticalc.QTableView2.QTableView2.select_cell
  magneticalc.QTableView2.QTableView2.html#select_cell
  Function
  Method
  PUBLIC
  Selects a cell. Any parameter may be left set to None in order to load its value from the selection model.
- magneticalc.QTableView2.QTableView2.select_last_row
  magneticalc.QTableView2.QTableView2.html#select_last_row
  Function
  Method
  PUBLIC
  Selects the last row.
- magneticalc.QTableView2.QTableView2.get_selected_row
  magneticalc.QTableView2.QTableView2.html#get_selected_row
  Function
  Method
  PUBLIC
  Returns the currently selected row index.
- magneticalc.QTableView2.QTableView2.on_selection_changed
  magneticalc.QTableView2.QTableView2.html#on_selection_changed
  Function
  Method
  PUBLIC
  Gets called when the selection changed.
- magneticalc.QTableView2.QTableView2.focusInEvent
  magneticalc.QTableView2.QTableView2.html#focusInEvent
  Function
  Method
  PUBLIC
  Gets called when the table gained focus. This highlights the border and selects the last-selected cell (if any).
- magneticalc.QTableView2.QTableView2.focusOutEvent
  magneticalc.QTableView2.QTableView2.html#focusOutEvent
  Function
  Method
  PUBLIC
  Gets called when the table lost focus, or when a cell is being edited. When not editing, this clears the selection, triggering `on_selection_changed()`.
- magneticalc.Constraint_Editor.Constraint_Editor
  magneticalc.Constraint_Editor.Constraint_Editor.html
  Class
  Class
  PUBLIC
  Constraint_Editor class.
- magneticalc.Constraint_Editor.Constraint_Editor.Constraint_Types
  magneticalc.Constraint_Editor.Constraint_Editor.html#Constraint_Types
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Constraint_Editor.Constraint_Editor.Constraint_Options
  magneticalc.Constraint_Editor.Constraint_Editor.html#Constraint_Options
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Constraint_Editor.Constraint_Editor.HTML
  magneticalc.Constraint_Editor.Constraint_Editor.html#HTML
  Attribute
  Constant
  PUBLIC
  Undocumented
- magneticalc.Constraint_Editor.Constraint_Editor.__init__
  magneticalc.Constraint_Editor.Constraint_Editor.html#__init__
  Function
  Method
  PUBLIC
  Prepares the constraint editor, but doesn't fully initialize it yet.
- magneticalc.Constraint_Editor.Constraint_Editor.gui
  magneticalc.Constraint_Editor.Constraint_Editor.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Constraint_Editor.Constraint_Editor._constraint_collection
  magneticalc.Constraint_Editor.Constraint_Editor.html#_constraint_collection
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Constraint_Editor.Constraint_Editor.table
  magneticalc.Constraint_Editor.Constraint_Editor.html#table
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Constraint_Editor.Constraint_Editor.text_browser
  magneticalc.Constraint_Editor.Constraint_Editor.html#text_browser
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Constraint_Editor.Constraint_Editor._changed
  magneticalc.Constraint_Editor.Constraint_Editor.html#_changed
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Constraint_Editor.Constraint_Editor.showEvent
  magneticalc.Constraint_Editor.Constraint_Editor.html#showEvent
  Function
  Method
  PUBLIC
  Gets called when the dialog is opened.
- magneticalc.Constraint_Editor.Constraint_Editor.changed
  magneticalc.Constraint_Editor.Constraint_Editor.html#changed
  Attribute
  Instance Variable
  PUBLIC
  Returns the "changed" state.
- magneticalc.Constraint_Editor.Constraint_Editor.changed.setter
  magneticalc.Constraint_Editor.Constraint_Editor.html#changed.setter
  Function
  Method
  PUBLIC
  Sets the "changed" state. This updates the window title.
- magneticalc.Constraint_Editor.Constraint_Editor.reload
  magneticalc.Constraint_Editor.Constraint_Editor.html#reload
  Function
  Method
  PUBLIC
  Reloads the constraint editor.
- magneticalc.Constraint_Editor.Constraint_Editor.update_table
  magneticalc.Constraint_Editor.Constraint_Editor.html#update_table
  Function
  Method
  PUBLIC
  Populates the table.
- magneticalc.Constraint_Editor.Constraint_Editor.rows
  magneticalc.Constraint_Editor.Constraint_Editor.html#rows
  Attribute
  Property
  PUBLIC
  Gets the list of rows (constraint groups).
- magneticalc.Constraint_Editor.Constraint_Editor.rows_count
  magneticalc.Constraint_Editor.Constraint_Editor.html#rows_count
  Attribute
  Property
  PUBLIC
  Gets the number of rows (constraint groups).
- magneticalc.Constraint_Editor.Constraint_Editor.get_constraints
  magneticalc.Constraint_Editor.Constraint_Editor.html#get_constraints
  Function
  Method
  PUBLIC
  Gets the list of constraints.
- magneticalc.Constraint_Editor.Constraint_Editor.on_table_row_added
  magneticalc.Constraint_Editor.Constraint_Editor.html#on_table_row_added
  Function
  Method
  PUBLIC
  Gets called after a row has been added to the table.
- magneticalc.Constraint_Editor.Constraint_Editor.on_table_cell_edited
  magneticalc.Constraint_Editor.Constraint_Editor.html#on_table_cell_edited
  Function
  Method
  PUBLIC
  Gets called after a table cell has been edited.
- magneticalc.Constraint_Editor.Constraint_Editor.on_table_row_deleted
  magneticalc.Constraint_Editor.Constraint_Editor.html#on_table_row_deleted
  Function
  Method
  PUBLIC
  Gets called after a row has been deleted from the table.
- magneticalc.QMessageBox2.QMessageBox2
  magneticalc.QMessageBox2.QMessageBox2.html
  Class
  Class
  PUBLIC
  QMessageBox2 class.
- magneticalc.QMessageBox2.QMessageBox2.__init__
  magneticalc.QMessageBox2.QMessageBox2.html#__init__
  Function
  Method
  PUBLIC
  Initializes a message box.
- magneticalc.QMessageBox2.QMessageBox2.choice
  magneticalc.QMessageBox2.QMessageBox2.html#choice
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.QMessageBox2.QMessageBox2.accepting
  magneticalc.QMessageBox2.QMessageBox2.html#accepting
  Function
  Method
  PUBLIC
  Sets the choice and accepts the dialog.
- magneticalc.QMessageBox2.QMessageBox2.rejecting
  magneticalc.QMessageBox2.QMessageBox2.html#rejecting
  Function
  Method
  PUBLIC
  Gets called when the user hits the ESC key.
- magneticalc.QtWidgets2.QGroupBox2.QGroupBox2
  magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.html
  Class
  Class
  PUBLIC
  QGroupBox2 class.
- magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.__init__
  magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.html#__init__
  Function
  Method
  PUBLIC
  Initializes a groupbox.
- magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.set_color
  magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.html#set_color
  Function
  Method
  PUBLIC
  Sets the style and label color of the groupbox.
- magneticalc.QtWidgets2.QHLine.QHLine
  magneticalc.QtWidgets2.QHLine.QHLine.html
  Class
  Class
  PUBLIC
  QHLine class.
- magneticalc.QtWidgets2.QHLine.QHLine.VerticalSpacing
  magneticalc.QtWidgets2.QHLine.QHLine.html#VerticalSpacing
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.QtWidgets2.QHLine.QHLine.__init__
  magneticalc.QtWidgets2.QHLine.QHLine.html#__init__
  Function
  Method
  PUBLIC
  Creates a horizontal line.
- magneticalc.QtWidgets2.QSliderFloat.QSliderFloat
  magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.html
  Class
  Class
  PUBLIC
  QSliderFloat class.
- magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.__init__
  magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.html#__init__
  Function
  Method
  PUBLIC
  Initializes a slider supporting float values.
- magneticalc.QtWidgets2.QSliderFloat.QSliderFloat._step
  magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.html#_step
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.setValue
  magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.html#setValue
  Function
  Method
  PUBLIC
  Sets the slider value.
- magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.get_value
  magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.html#get_value
  Function
  Method
  PUBLIC
  Returns the slider value.
- magneticalc.QtWidgets2.QSpinBox2.QSpinBox2
  magneticalc.QtWidgets2.QSpinBox2.QSpinBox2.html
  Class
  Class
  PUBLIC
  QSpinBox2 class.
- magneticalc.QtWidgets2.QSpinBox2.QSpinBox2.__init__
  magneticalc.QtWidgets2.QSpinBox2.QSpinBox2.html#__init__
  Function
  Method
  PUBLIC
  Initializes a spinbox.
- magneticalc.QtWidgets2.QHBoxLayout2.QHBoxLayout2
  magneticalc.QtWidgets2.QHBoxLayout2.QHBoxLayout2.html
  Class
  Class
  PUBLIC
  QHBoxLayout2 class.
- magneticalc.QtWidgets2.QHBoxLayout2.QHBoxLayout2.__init__
  magneticalc.QtWidgets2.QHBoxLayout2.QHBoxLayout2.html#__init__
  Function
  Method
  PUBLIC
  Initializes a horizontal layout with multiple elements at once.
- magneticalc.OverridePadding_Dialog.OverridePadding_Dialog
  magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.html
  Class
  Class
  PUBLIC
  OverridePadding_Dialog class.
- magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.BoundsRange
  magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.html#BoundsRange
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.__init__
  magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.html#__init__
  Function
  Method
  PUBLIC
  Initializes the dialog.
- magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.gui
  magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.bounds_min_spinbox
  magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.html#bounds_min_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.bounds_max_spinbox
  magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.html#bounds_max_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.buttons
  magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.html#buttons
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.validate
  magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.html#validate
  Function
  Method
  PUBLIC
  Validates the bounding box values and enables/disables the "Apply" button accordingly.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html
  Class
  Class
  PUBLIC
  SamplingVolume_Widget class.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.UnitsLabelWidth
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#UnitsLabelWidth
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.PaddingMin
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#PaddingMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.PaddingMax
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#PaddingMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.ResolutionOptionsDict
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#ResolutionOptionsDict
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.__init__
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#__init__
  Function
  Method
  PUBLIC
  Populates the widget.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.gui
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.constraint_editor
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#constraint_editor
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.padding_widget
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#padding_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.padding_spinbox
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#padding_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_extent_label
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#total_extent_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_constraints_label
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#total_constraints_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.resolution_combobox
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#resolution_combobox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.resolution_units_label
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#resolution_units_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_points_label
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#total_points_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.reload
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#reload
  Function
  Method
  PUBLIC
  Reloads the widget.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.update
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#update
  Function
  Method
  PUBLIC
  Updates the widget.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.update_labels
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#update_labels
  Function
  Method
  PUBLIC
  Updates the labels.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.update_controls
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#update_controls
  Function
  Method
  PUBLIC
  Updates the controls.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.update_padding
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#update_padding
  Function
  Method
  PUBLIC
  Updates padding.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.clear_padding
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#clear_padding
  Function
  Method
  PUBLIC
  Clears the padding values.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.override_padding
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#override_padding
  Function
  Method
  PUBLIC
  Override padding, setting the bounding box directly.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.open_constraint_editor
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#open_constraint_editor
  Function
  Method
  PUBLIC
  Opens the constraint editor. Recalculates the sampling volume if the constraints changed.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.set_sampling_volume
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#set_sampling_volume
  Function
  Method
  PUBLIC
  Sets the sampling volume. This will overwrite the currently set sampling volume in the model. Any underscored parameter may be left set to None in order to load its default value.
- magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.readjust
  magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.html#readjust
  Function
  Method
  PUBLIC
  Readjusts the sampling volume to the currently set wire bounds and padding. This also readjusts the minimum padding bounds in case the wire bounds have shrunk too far.
- magneticalc.SamplingVolume.SamplingVolume
  magneticalc.SamplingVolume.SamplingVolume.html
  Class
  Class
  PUBLIC
  Sampling volume class.
- magneticalc.SamplingVolume.SamplingVolume.__init__
  magneticalc.SamplingVolume.SamplingVolume.html#__init__
  Function
  Method
  PUBLIC
  Initializes an empty sampling volume, with zero bounds and no constraints.
- magneticalc.SamplingVolume.SamplingVolume._bounds_min
  magneticalc.SamplingVolume.SamplingVolume.html#_bounds_min
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume._bounds_max
  magneticalc.SamplingVolume.SamplingVolume.html#_bounds_max
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume._dimension
  magneticalc.SamplingVolume.SamplingVolume.html#_dimension
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume._points
  magneticalc.SamplingVolume.SamplingVolume.html#_points
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume._permeabilities
  magneticalc.SamplingVolume.SamplingVolume.html#_permeabilities
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume._labeled_indices
  magneticalc.SamplingVolume.SamplingVolume.html#_labeled_indices
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume._neighbor_indices
  magneticalc.SamplingVolume.SamplingVolume.html#_neighbor_indices
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume.resolution
  magneticalc.SamplingVolume.SamplingVolume.html#resolution
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume._label_resolution
  magneticalc.SamplingVolume.SamplingVolume.html#_label_resolution
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume._constraints
  magneticalc.SamplingVolume.SamplingVolume.html#_constraints
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.SamplingVolume.SamplingVolume.set
  magneticalc.SamplingVolume.SamplingVolume.html#set
  Function
  Method
  PUBLIC
  Sets the parameters.
- magneticalc.SamplingVolume.SamplingVolume.bounds
  magneticalc.SamplingVolume.SamplingVolume.html#bounds
  Attribute
  Property
  PUBLIC
  Returns this volume's bounding box.
- magneticalc.SamplingVolume.SamplingVolume.extent
  magneticalc.SamplingVolume.SamplingVolume.html#extent
  Attribute
  Property
  PUBLIC
  Returns this volume's extent.
- magneticalc.SamplingVolume.SamplingVolume.set_bounds_nearest
  magneticalc.SamplingVolume.SamplingVolume.html#set_bounds_nearest
  Function
  Method
  PUBLIC
  Adjusts this volume's bounding box to fully enclose a 3D wire curve. This expands the bounding box to the next integer grid coordinates.
- magneticalc.SamplingVolume.SamplingVolume.set_padding_nearest
  magneticalc.SamplingVolume.SamplingVolume.html#set_padding_nearest
  Function
  Method
  PUBLIC
  Shrinks or enlarges this volume's bounding box by some amount, in each direction, symmetrically. This shrinks or expands the bounding box to the next integer grid coordinates.
- magneticalc.SamplingVolume.SamplingVolume._i_to_xyz
  magneticalc.SamplingVolume.SamplingVolume.html#_i_to_xyz
  Function
  Method
  PRIVATE
  Convert 1D index to 3D indices. Note: "Fortran" indexing (column-major order).
- magneticalc.SamplingVolume.SamplingVolume._xyz_to_i
  magneticalc.SamplingVolume.SamplingVolume.html#_xyz_to_i
  Function
  Method
  PRIVATE
  Convert 3D indices to 1D index. Note: "Fortran" indexing (column-major order).
- magneticalc.SamplingVolume.SamplingVolume.recalculate
  magneticalc.SamplingVolume.SamplingVolume.html#recalculate
  Function
  Method
  PUBLIC
  Recalculates the sampling volume points, permeabilities, labels and neighborhoods according to the constraints.
- magneticalc.SamplingVolume.SamplingVolume.dimension
  magneticalc.SamplingVolume.SamplingVolume.html#dimension
  Attribute
  Property
  PUBLIC
  Sampling volume dimension if it is valid, None otherwise.
- magneticalc.SamplingVolume.SamplingVolume.points
  magneticalc.SamplingVolume.SamplingVolume.html#points
  Attribute
  Property
  PUBLIC
  Returns this sampling volume's points.
- magneticalc.SamplingVolume.SamplingVolume.points_count
  magneticalc.SamplingVolume.SamplingVolume.html#points_count
  Attribute
  Property
  PUBLIC
  Returns this sampling volume's point count.
- magneticalc.SamplingVolume.SamplingVolume.permeabilities
  magneticalc.SamplingVolume.SamplingVolume.html#permeabilities
  Attribute
  Property
  PUBLIC
  Returns this sampling volume's relative permeabilities µ_r.
- magneticalc.SamplingVolume.SamplingVolume.labeled_indices
  magneticalc.SamplingVolume.SamplingVolume.html#labeled_indices
  Attribute
  Property
  PUBLIC
  Returns this sampling volume's labeled indices.
- magneticalc.SamplingVolume.SamplingVolume.labels_count
  magneticalc.SamplingVolume.SamplingVolume.html#labels_count
  Attribute
  Property
  PUBLIC
  Returns this sampling volume's label count.
- magneticalc.SamplingVolume.SamplingVolume.neighbor_indices
  magneticalc.SamplingVolume.SamplingVolume.html#neighbor_indices
  Attribute
  Property
  PUBLIC
  Returns this sampling volume's neighborhood indices.
- magneticalc.Wire.Wire
  magneticalc.Wire.Wire.html
  Class
  Class
  PUBLIC
  Wire class.
- magneticalc.Wire.Wire.__init__
  magneticalc.Wire.Wire.html#__init__
  Function
  Method
  PUBLIC
  Initializes an empty wire. A 3D piecewise linear curve with some DC current associated with it.
- magneticalc.Wire.Wire.points_base
  magneticalc.Wire.Wire.html#points_base
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire.Wire.points_transformed
  magneticalc.Wire.Wire.html#points_transformed
  Attribute
  Instance Variable
  PUBLIC
  Bounding box: Minimum bounds (3D point), maximum bounds (3D point).
- magneticalc.Wire.Wire.bounds
  magneticalc.Wire.Wire.html#bounds
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire.Wire._slicer_limit
  magneticalc.Wire.Wire.html#_slicer_limit
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Wire.Wire.dc
  magneticalc.Wire.Wire.html#dc
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire.Wire._points_sliced
  magneticalc.Wire.Wire.html#_points_sliced
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Wire.Wire._length
  magneticalc.Wire.Wire.html#_length
  Attribute
  Instance Variable
  PRIVATE
  Wire Elements: Ordered list of segment center points and directions.
- magneticalc.Wire.Wire._elements
  magneticalc.Wire.Wire.html#_elements
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Wire.Wire.set
  magneticalc.Wire.Wire.html#set
  Function
  Method
  PUBLIC
  Sets the parameters.
- magneticalc.Wire.Wire._transform_stretch
  magneticalc.Wire.Wire.html#_transform_stretch
  Function
  Static Method
  PRIVATE
  This transformation stretches (and/or mirrors) this curve by some factor in any direction. Use the factor +1 / -1 to retain / mirror the curve in that direction.
- magneticalc.Wire.Wire._transform_rotational_symmetry
  magneticalc.Wire.Wire.html#_transform_rotational_symmetry
  Function
  Static Method
  PRIVATE
  This transformation replicates and rotates this curve `count` times about an `axis` with radius `radius`.
- magneticalc.Wire.Wire.recalculate
  magneticalc.Wire.Wire.html#recalculate
  Function
  Method
  PUBLIC
  Slices wire segments into smaller ones until segment lengths equal or undershoot slicer limit.
- magneticalc.Wire.Wire.points_sliced
  magneticalc.Wire.Wire.html#points_sliced
  Attribute
  Property
  PUBLIC
  Returns this wire's points after slicing.
- magneticalc.Wire.Wire.length
  magneticalc.Wire.Wire.html#length
  Attribute
  Property
  PUBLIC
  Wire length
- magneticalc.Wire.Wire.elements
  magneticalc.Wire.Wire.html#elements
  Attribute
  Property
  PUBLIC
  Wire elements
- magneticalc.Field.Field
  magneticalc.Field.Field.html
  Class
  Class
  PUBLIC
  Field class.
- magneticalc.Field.Field.__init__
  magneticalc.Field.Field.html#__init__
  Function
  Method
  PUBLIC
  Initializes a field.
- magneticalc.Field.Field.type
  magneticalc.Field.Field.html#type
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Field.Field._distance_limit
  magneticalc.Field.Field.html#_distance_limit
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Field.Field._length_scale
  magneticalc.Field.Field.html#_length_scale
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Field.Field._total_calculations
  magneticalc.Field.Field.html#_total_calculations
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Field.Field._total_skipped_calculations
  magneticalc.Field.Field.html#_total_skipped_calculations
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Field.Field._vectors
  magneticalc.Field.Field.html#_vectors
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Field.Field.set
  magneticalc.Field.Field.html#set
  Function
  Method
  PUBLIC
  Sets the parameters.
- magneticalc.Field.Field.get_units
  magneticalc.Field.Field.html#get_units
  Function
  Method
  PUBLIC
  Gets field units.
- magneticalc.Field.Field.recalculate
  magneticalc.Field.Field.html#recalculate
  Function
  Method
  PUBLIC
  Recalculates field vectors.
- magneticalc.Field.Field.vectors
  magneticalc.Field.Field.html#vectors
  Attribute
  Property
  PUBLIC
  Gets field vectors. (The selected field type determined which field was calculated.)
- magneticalc.Field.Field.vectors_count
  magneticalc.Field.Field.html#vectors_count
  Attribute
  Property
  PUBLIC
  Number of field vectors
- magneticalc.Field.Field.total_calculations
  magneticalc.Field.Field.html#total_calculations
  Attribute
  Property
  PUBLIC
  Gets total number of calculations.
- magneticalc.Field.Field.total_skipped_calculations
  magneticalc.Field.Field.html#total_skipped_calculations
  Attribute
  Property
  PUBLIC
  Gets total number of skipped calculations.
- magneticalc.Field.Field.get_arrows
  magneticalc.Field.Field.html#get_arrows
  Function
  Static Method
  PUBLIC
  Returns the field arrow parameters needed by `VisPyCanvas`.
- magneticalc.VisPyCanvas.VisPyCanvas
  magneticalc.VisPyCanvas.VisPyCanvas.html
  Class
  Class
  PUBLIC
  VisPyCanvas class.
- magneticalc.VisPyCanvas.VisPyCanvas.DefaultFontSize
  magneticalc.VisPyCanvas.VisPyCanvas.html#DefaultFontSize
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.DebugVisuals
  magneticalc.VisPyCanvas.VisPyCanvas.html#DebugVisuals
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.DebugPerspective
  magneticalc.VisPyCanvas.VisPyCanvas.html#DebugPerspective
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.White
  magneticalc.VisPyCanvas.VisPyCanvas.html#White
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.Black
  magneticalc.VisPyCanvas.VisPyCanvas.html#Black
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.FieldArrowHeadSize
  magneticalc.VisPyCanvas.VisPyCanvas.html#FieldArrowHeadSize
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.FieldPointSize
  magneticalc.VisPyCanvas.VisPyCanvas.html#FieldPointSize
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.WirePointSize
  magneticalc.VisPyCanvas.VisPyCanvas.html#WirePointSize
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.WirePointSelectedSize
  magneticalc.VisPyCanvas.VisPyCanvas.html#WirePointSelectedSize
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.WirePointSelectedColor
  magneticalc.VisPyCanvas.VisPyCanvas.html#WirePointSelectedColor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.ScaleFactorMin
  magneticalc.VisPyCanvas.VisPyCanvas.html#ScaleFactorMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.ScaleFactorMax
  magneticalc.VisPyCanvas.VisPyCanvas.html#ScaleFactorMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.MagnitudeLimit
  magneticalc.VisPyCanvas.VisPyCanvas.html#MagnitudeLimit
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.MagnitudePrecision
  magneticalc.VisPyCanvas.VisPyCanvas.html#MagnitudePrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.__init__
  magneticalc.VisPyCanvas.VisPyCanvas.html#__init__
  Function
  Method
  PUBLIC
  Initialize VisPy canvas.
- magneticalc.VisPyCanvas.VisPyCanvas.gui
  magneticalc.VisPyCanvas.VisPyCanvas.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.redraw_start_time
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw_start_time
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.view_main
  magneticalc.VisPyCanvas.VisPyCanvas.html#view_main
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.view_text
  magneticalc.VisPyCanvas.VisPyCanvas.html#view_text
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.font_manager
  magneticalc.VisPyCanvas.VisPyCanvas.html#font_manager
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_perspective_info
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_perspective_info
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_field_labels
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_field_labels
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_coordinate_system
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_coordinate_system
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_segments
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_wire_segments
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_points_selected
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_wire_points_selected
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_points_sliced
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_wire_points_sliced
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_field_points
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_field_points
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_field_arrow_lines
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_field_arrow_lines
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_field_arrow_heads
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_field_arrow_heads
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.foreground
  magneticalc.VisPyCanvas.VisPyCanvas.html#foreground
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.background
  magneticalc.VisPyCanvas.VisPyCanvas.html#background
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.initializing
  magneticalc.VisPyCanvas.VisPyCanvas.html#initializing
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.visual_startup_info
  magneticalc.VisPyCanvas.VisPyCanvas.html#visual_startup_info
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.signals_blocked
  magneticalc.VisPyCanvas.VisPyCanvas.html#signals_blocked
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.super_perspective_changed
  magneticalc.VisPyCanvas.VisPyCanvas.html#super_perspective_changed
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.update_color_scheme
  magneticalc.VisPyCanvas.VisPyCanvas.html#update_color_scheme
  Function
  Method
  PUBLIC
  Updates the color scheme.
- magneticalc.VisPyCanvas.VisPyCanvas.bgcolor
  magneticalc.VisPyCanvas.VisPyCanvas.html#bgcolor
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.VisPyCanvas.VisPyCanvas.set_visible
  magneticalc.VisPyCanvas.VisPyCanvas.html#set_visible
  Function
  Method
  PUBLIC
  Sets some visual's visibility.
- magneticalc.VisPyCanvas.VisPyCanvas.load_perspective
  magneticalc.VisPyCanvas.VisPyCanvas.html#load_perspective
  Function
  Method
  PUBLIC
  Loads perspective from project.
- magneticalc.VisPyCanvas.VisPyCanvas.on_perspective_changed
  magneticalc.VisPyCanvas.VisPyCanvas.html#on_perspective_changed
  Function
  Method
  PUBLIC
  Handles a change of perspective.
- magneticalc.VisPyCanvas.VisPyCanvas.redraw_perspective_info
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw_perspective_info
  Function
  Method
  PUBLIC
  Redraws the perspective info text.
- magneticalc.VisPyCanvas.VisPyCanvas.redraw
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw
  Function
  Method
  PUBLIC
  Redraws the canvas.
- magneticalc.VisPyCanvas.VisPyCanvas.redraw_wire_segments
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw_wire_segments
  Function
  Method
  PUBLIC
  Redraws wire segments.
- magneticalc.VisPyCanvas.VisPyCanvas.redraw_wire_points_sliced
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw_wire_points_sliced
  Function
  Method
  PUBLIC
  Redraws sliced wire points.
- magneticalc.VisPyCanvas.VisPyCanvas.redraw_wire_points_selected
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw_wire_points_selected
  Function
  Method
  PUBLIC
  Redraws selected wire base points.
- magneticalc.VisPyCanvas.VisPyCanvas.redraw_field_arrows
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw_field_arrows
  Function
  Method
  PUBLIC
  Redraws field arrows.
- magneticalc.VisPyCanvas.VisPyCanvas.redraw_field_points
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw_field_points
  Function
  Method
  PUBLIC
  Redraws field points.
- magneticalc.VisPyCanvas.VisPyCanvas.create_field_labels
  magneticalc.VisPyCanvas.VisPyCanvas.html#create_field_labels
  Function
  Method
  PUBLIC
  Creates field labels.
- magneticalc.VisPyCanvas.VisPyCanvas.delete_field_labels
  magneticalc.VisPyCanvas.VisPyCanvas.html#delete_field_labels
  Function
  Method
  PUBLIC
  Deletes the field labels.
- magneticalc.VisPyCanvas.VisPyCanvas.redraw_field_labels
  magneticalc.VisPyCanvas.VisPyCanvas.html#redraw_field_labels
  Function
  Method
  PUBLIC
  Redraws field labels.
- magneticalc.VisPyCanvas.VisPyCanvas.save_image
  magneticalc.VisPyCanvas.VisPyCanvas.html#save_image
  Function
  Method
  PUBLIC
  Saves the currently displayed scene to PNG file.
- magneticalc.Display_Widget.Display_Widget
  magneticalc.Display_Widget.Display_Widget.html
  Class
  Class
  PUBLIC
  Display_Widget class.
- magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleMin
  magneticalc.Display_Widget.Display_Widget.html#FieldArrowHeadScaleMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleMax
  magneticalc.Display_Widget.Display_Widget.html#FieldArrowHeadScaleMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleStep
  magneticalc.Display_Widget.Display_Widget.html#FieldArrowHeadScaleStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleMin
  magneticalc.Display_Widget.Display_Widget.html#FieldArrowLineScaleMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleMax
  magneticalc.Display_Widget.Display_Widget.html#FieldArrowLineScaleMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleStep
  magneticalc.Display_Widget.Display_Widget.html#FieldArrowLineScaleStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldPointScaleMin
  magneticalc.Display_Widget.Display_Widget.html#FieldPointScaleMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldPointScaleMax
  magneticalc.Display_Widget.Display_Widget.html#FieldPointScaleMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldPointScaleStep
  magneticalc.Display_Widget.Display_Widget.html#FieldPointScaleStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldBoostMin
  magneticalc.Display_Widget.Display_Widget.html#FieldBoostMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldBoostMax
  magneticalc.Display_Widget.Display_Widget.html#FieldBoostMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.FieldBoostStep
  magneticalc.Display_Widget.Display_Widget.html#FieldBoostStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.ExcessiveFieldLabelsThreshold
  magneticalc.Display_Widget.Display_Widget.html#ExcessiveFieldLabelsThreshold
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.__init__
  magneticalc.Display_Widget.Display_Widget.html#__init__
  Function
  Method
  PUBLIC
  Populates the widget.
- magneticalc.Display_Widget.Display_Widget.gui
  magneticalc.Display_Widget.Display_Widget.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.field_point_scale_slider
  magneticalc.Display_Widget.Display_Widget.html#field_point_scale_slider
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.field_arrow_head_scale_slider
  magneticalc.Display_Widget.Display_Widget.html#field_arrow_head_scale_slider
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.field_arrow_line_scale_slider
  magneticalc.Display_Widget.Display_Widget.html#field_arrow_line_scale_slider
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.field_boost_slider
  magneticalc.Display_Widget.Display_Widget.html#field_boost_slider
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.display_field_magnitude_labels_checkbox
  magneticalc.Display_Widget.Display_Widget.html#display_field_magnitude_labels_checkbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.field_label_resolution_combobox
  magneticalc.Display_Widget.Display_Widget.html#field_label_resolution_combobox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.field_label_resolution_combobox_connection
  magneticalc.Display_Widget.Display_Widget.html#field_label_resolution_combobox_connection
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.total_labels_label
  magneticalc.Display_Widget.Display_Widget.html#total_labels_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Display_Widget.Display_Widget.reload
  magneticalc.Display_Widget.Display_Widget.html#reload
  Function
  Method
  PUBLIC
  Reloads the widget.
- magneticalc.Display_Widget.Display_Widget.update
  magneticalc.Display_Widget.Display_Widget.html#update
  Function
  Method
  PUBLIC
  Updates this widget.
- magneticalc.Display_Widget.Display_Widget.update_labels
  magneticalc.Display_Widget.Display_Widget.html#update_labels
  Function
  Method
  PUBLIC
  Updates the labels.
- magneticalc.Display_Widget.Display_Widget.update_controls
  magneticalc.Display_Widget.Display_Widget.html#update_controls
  Function
  Method
  PUBLIC
  Updates the field label resolution combobox.
- magneticalc.Display_Widget.Display_Widget.set_field_point_scale
  magneticalc.Display_Widget.Display_Widget.html#set_field_point_scale
  Function
  Method
  PUBLIC
  Sets field point scale.
- magneticalc.Display_Widget.Display_Widget.set_field_arrow_head_scale
  magneticalc.Display_Widget.Display_Widget.html#set_field_arrow_head_scale
  Function
  Method
  PUBLIC
  Sets field arrow head scale.
- magneticalc.Display_Widget.Display_Widget.set_field_arrow_line_scale
  magneticalc.Display_Widget.Display_Widget.html#set_field_arrow_line_scale
  Function
  Method
  PUBLIC
  Sets field arrow line scale.
- magneticalc.Display_Widget.Display_Widget.set_field_boost
  magneticalc.Display_Widget.Display_Widget.html#set_field_boost
  Function
  Method
  PUBLIC
  Sets field boost value.
- magneticalc.Display_Widget.Display_Widget.set_display_field_magnitude_labels
  magneticalc.Display_Widget.Display_Widget.html#set_display_field_magnitude_labels
  Function
  Method
  PUBLIC
  Sets field label "Display Magnitude" value.
- magneticalc.Display_Widget.Display_Widget.set_field_label_resolution
  magneticalc.Display_Widget.Display_Widget.html#set_field_label_resolution
  Function
  Method
  PUBLIC
  Sets field label resolution exponent.
- magneticalc.Display_Widget.Display_Widget.disable_field_labels
  magneticalc.Display_Widget.Display_Widget.html#disable_field_labels
  Function
  Method
  PUBLIC
  Disables field labels.
- magneticalc.Display_Widget.Display_Widget.prevent_excessive_field_labels
  magneticalc.Display_Widget.Display_Widget.html#prevent_excessive_field_labels
  Function
  Method
  PUBLIC
  Prevents displaying an excessive number of field labels.
- magneticalc.QtWidgets2.QSaveAction.QSaveAction
  magneticalc.QtWidgets2.QSaveAction.QSaveAction.html
  Class
  Class
  PUBLIC
  QSaveAction class.
- magneticalc.QtWidgets2.QSaveAction.QSaveAction.__init__
  magneticalc.QtWidgets2.QSaveAction.QSaveAction.html#__init__
  Function
  Method
  PUBLIC
  Initializes a save dialog.
- magneticalc.QtWidgets2.QSaveAction.QSaveAction.filename
  magneticalc.QtWidgets2.QSaveAction.QSaveAction.html#filename
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.ExportContainer_Dialog.ExportContainer_Dialog
  magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.html
  Class
  Class
  PUBLIC
  ExportContainer_Dialog class.
- magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.__init__
  magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.html#__init__
  Function
  Method
  PUBLIC
  Initializes the dialog.
- magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.gui
  magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.Export_Names_Available_Map
  magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.html#Export_Names_Available_Map
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.checkboxes
  magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.html#checkboxes
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.export
  magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.html#export
  Function
  Method
  PUBLIC
  Exports wire points, current and fields to some HDF5 container file.
- magneticalc.QtWidgets2.QDoubleSpinBox2.QDoubleSpinBox2
  magneticalc.QtWidgets2.QDoubleSpinBox2.QDoubleSpinBox2.html
  Class
  Class
  PUBLIC
  QDoubleSpinBox2 class.
- magneticalc.QtWidgets2.QDoubleSpinBox2.QDoubleSpinBox2.__init__
  magneticalc.QtWidgets2.QDoubleSpinBox2.QDoubleSpinBox2.html#__init__
  Function
  Method
  PUBLIC
  Initializes a floating-point spinbox.
- magneticalc.Field_Widget.Field_Widget
  magneticalc.Field_Widget.Field_Widget.html
  Class
  Class
  PUBLIC
  Field_Widget class.
- magneticalc.Field_Widget.Field_Widget.DistanceLimitMin
  magneticalc.Field_Widget.Field_Widget.html#DistanceLimitMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.DistanceLimitMax
  magneticalc.Field_Widget.Field_Widget.html#DistanceLimitMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.DistanceLimitStep
  magneticalc.Field_Widget.Field_Widget.html#DistanceLimitStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.DistanceLimitPrecision
  magneticalc.Field_Widget.Field_Widget.html#DistanceLimitPrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.__init__
  magneticalc.Field_Widget.Field_Widget.html#__init__
  Function
  Method
  PUBLIC
  Populates the widget.
- magneticalc.Field_Widget.Field_Widget.gui
  magneticalc.Field_Widget.Field_Widget.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.field_type_group
  magneticalc.Field_Widget.Field_Widget.html#field_type_group
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.field_type_checkboxes
  magneticalc.Field_Widget.Field_Widget.html#field_type_checkboxes
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.total_calculations_label
  magneticalc.Field_Widget.Field_Widget.html#total_calculations_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.distance_limit_spinbox
  magneticalc.Field_Widget.Field_Widget.html#distance_limit_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.total_skipped_calculations_label
  magneticalc.Field_Widget.Field_Widget.html#total_skipped_calculations_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Field_Widget.Field_Widget.reload
  magneticalc.Field_Widget.Field_Widget.html#reload
  Function
  Method
  PUBLIC
  Reloads the widget.
- magneticalc.Field_Widget.Field_Widget.update
  magneticalc.Field_Widget.Field_Widget.html#update
  Function
  Method
  PUBLIC
  Updates this widget.
- magneticalc.Field_Widget.Field_Widget.update_labels
  magneticalc.Field_Widget.Field_Widget.html#update_labels
  Function
  Method
  PUBLIC
  Updates the labels.
- magneticalc.Field_Widget.Field_Widget.update_controls
  magneticalc.Field_Widget.Field_Widget.html#update_controls
  Function
  Method
  PUBLIC
  Updates the controls.
- magneticalc.Field_Widget.Field_Widget.on_field_type_changed
  magneticalc.Field_Widget.Field_Widget.html#on_field_type_changed
  Function
  Method
  PUBLIC
  Gets called when the field type changed.
- magneticalc.Field_Widget.Field_Widget.set_field
  magneticalc.Field_Widget.Field_Widget.html#set_field
  Function
  Method
  PUBLIC
  Sets the field. This will replace the currently set field in the model. Any underscored parameter may be left set to None in order to load its default value.
- magneticalc.File_Menu.File_Menu
  magneticalc.File_Menu.File_Menu.html
  Class
  Class
  PUBLIC
  File_Menu class.
- magneticalc.File_Menu.File_Menu.__init__
  magneticalc.File_Menu.File_Menu.html#__init__
  Function
  Method
  PUBLIC
  Initializes the menu.
- magneticalc.File_Menu.File_Menu.gui
  magneticalc.File_Menu.File_Menu.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.File_Menu.File_Menu.update
  magneticalc.File_Menu.File_Menu.html#update
  Function
  Method
  PUBLIC
  Updates the menu.
- magneticalc.File_Menu.File_Menu.new_project
  magneticalc.File_Menu.File_Menu.html#new_project
  Function
  Method
  PUBLIC
  Creates a new project with an INI file.
- magneticalc.File_Menu.File_Menu.open_project
  magneticalc.File_Menu.File_Menu.html#open_project
  Function
  Method
  PUBLIC
  Opens a project from an INI file.
- magneticalc.File_Menu.File_Menu.save_project_as
  magneticalc.File_Menu.File_Menu.html#save_project_as
  Function
  Method
  PUBLIC
  Saves the project to an INI file.
- magneticalc.File_Menu.File_Menu.close_project
  magneticalc.File_Menu.File_Menu.html#close_project
  Function
  Method
  PUBLIC
  Closes the project and loads the default project.
- magneticalc.File_Menu.File_Menu.export_image
  magneticalc.File_Menu.File_Menu.html#export_image
  Function
  Method
  PUBLIC
  Exports the currently displayed scene to a PNG file.
- magneticalc.Usage_Dialog.Usage_Dialog
  magneticalc.Usage_Dialog.Usage_Dialog.html
  Class
  Class
  PUBLIC
  Usage_Dialog class.
- magneticalc.Usage_Dialog.Usage_Dialog.HTML
  magneticalc.Usage_Dialog.Usage_Dialog.html#HTML
  Attribute
  Constant
  PUBLIC
  Undocumented
- magneticalc.Usage_Dialog.Usage_Dialog.__init__
  magneticalc.Usage_Dialog.Usage_Dialog.html#__init__
  Function
  Method
  PUBLIC
  Initializes "Usage" dialog.
- magneticalc.Help_Menu.Help_Menu
  magneticalc.Help_Menu.Help_Menu.html
  Class
  Class
  PUBLIC
  Help_Menu class.
- magneticalc.Help_Menu.Help_Menu.__init__
  magneticalc.Help_Menu.Help_Menu.html#__init__
  Function
  Method
  PUBLIC
  Initializes the menu.
- magneticalc.Help_Menu.Help_Menu.gui
  magneticalc.Help_Menu.Help_Menu.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Help_Menu.Help_Menu.update
  magneticalc.Help_Menu.Help_Menu.html#update
  Function
  Method
  PUBLIC
  Updates the menu.
- magneticalc.Options_Menu.Options_Menu
  magneticalc.Options_Menu.Options_Menu.html
  Class
  Class
  PUBLIC
  Options_Menu class.
- magneticalc.Options_Menu.Options_Menu.__init__
  magneticalc.Options_Menu.Options_Menu.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- magneticalc.Options_Menu.Options_Menu.gui
  magneticalc.Options_Menu.Options_Menu.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Options_Menu.Options_Menu.options_backend_group
  magneticalc.Options_Menu.Options_Menu.html#options_backend_group
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Options_Menu.Options_Menu.backend_actions
  magneticalc.Options_Menu.Options_Menu.html#backend_actions
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Options_Menu.Options_Menu.update
  magneticalc.Options_Menu.Options_Menu.html#update
  Function
  Method
  PUBLIC
  Updates the menu.
- magneticalc.Options_Menu.Options_Menu.on_backend_changed
  magneticalc.Options_Menu.Options_Menu.html#on_backend_changed
  Function
  Method
  PUBLIC
  Gets called when the backend changed.
- magneticalc.QCheckboxConfig.QCheckboxConfig
  magneticalc.QCheckboxConfig.QCheckboxConfig.html
  Class
  Class
  PUBLIC
  QCheckboxConfig class.
- magneticalc.QCheckboxConfig.QCheckboxConfig.__init__
  magneticalc.QCheckboxConfig.QCheckboxConfig.html#__init__
  Function
  Method
  PUBLIC
  Initializes a manager for configuration bound checkbox actions.
- magneticalc.QCheckboxConfig.QCheckboxConfig.gui
  magneticalc.QCheckboxConfig.QCheckboxConfig.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.QCheckboxConfig.QCheckboxConfig.actions
  magneticalc.QCheckboxConfig.QCheckboxConfig.html#actions
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.QCheckboxConfig.QCheckboxConfig.add
  magneticalc.QCheckboxConfig.QCheckboxConfig.html#add
  Function
  Method
  PUBLIC
  Creates a checkbox action. The checkbox state is bound to the project configuration.
- magneticalc.QCheckboxConfig.QCheckboxConfig.changed
  magneticalc.QCheckboxConfig.QCheckboxConfig.html#changed
  Function
  Method
  PUBLIC
  Handles change of checkbox state.
- magneticalc.QCheckboxConfig.QCheckboxConfig.reload
  magneticalc.QCheckboxConfig.QCheckboxConfig.html#reload
  Function
  Method
  PUBLIC
  Reloads the configuration bound checkboxes.
- magneticalc.View_Menu.View_Menu
  magneticalc.View_Menu.View_Menu.html
  Class
  Class
  PUBLIC
  View_Menu class.
- magneticalc.View_Menu.View_Menu.__init__
  magneticalc.View_Menu.View_Menu.html#__init__
  Function
  Method
  PUBLIC
  Initializes the menu.
- magneticalc.View_Menu.View_Menu.gui
  magneticalc.View_Menu.View_Menu.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.View_Menu.View_Menu.checkbox_config
  magneticalc.View_Menu.View_Menu.html#checkbox_config
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.View_Menu.View_Menu.update
  magneticalc.View_Menu.View_Menu.html#update
  Function
  Method
  PUBLIC
  Updates the menu.
- magneticalc.View_Menu.View_Menu.on_show_gauss_changed
  magneticalc.View_Menu.View_Menu.html#on_show_gauss_changed
  Function
  Method
  PUBLIC
  Gets called when the "Show Gauss instead of Tesla" option changed.
- magneticalc.Wire_Widget.DefaultStretch
  magneticalc.Wire_Widget.html#DefaultStretch
  Attribute
  Variable
  PUBLIC
  Default rotational symmetry setting.
- magneticalc.Wire_Widget.DefaultRotationalSymmetry
  magneticalc.Wire_Widget.html#DefaultRotationalSymmetry
  Attribute
  Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget
  magneticalc.Wire_Widget.Wire_Widget.html
  Class
  Class
  PUBLIC
  Wire_Widget class.
- magneticalc.Wire_Widget.Wire_Widget.UnitsLabelWidth
  magneticalc.Wire_Widget.Wire_Widget.html#UnitsLabelWidth
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.StretchMin
  magneticalc.Wire_Widget.Wire_Widget.html#StretchMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.StretchMax
  magneticalc.Wire_Widget.Wire_Widget.html#StretchMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.StretchStep
  magneticalc.Wire_Widget.Wire_Widget.html#StretchStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.StretchPrecision
  magneticalc.Wire_Widget.Wire_Widget.html#StretchPrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryCountMin
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryCountMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryCountMax
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryCountMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusMin
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryRadiusMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusMax
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryRadiusMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusStep
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryRadiusStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusPrecision
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryRadiusPrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetMin
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryOffsetMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetMax
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryOffsetMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetStep
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryOffsetStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetPrecision
  magneticalc.Wire_Widget.Wire_Widget.html#RotationalSymmetryOffsetPrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.SlicerLimitMin
  magneticalc.Wire_Widget.Wire_Widget.html#SlicerLimitMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.SlicerLimitMax
  magneticalc.Wire_Widget.Wire_Widget.html#SlicerLimitMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.SlicerLimitStep
  magneticalc.Wire_Widget.Wire_Widget.html#SlicerLimitStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.SlicerLimitPrecision
  magneticalc.Wire_Widget.Wire_Widget.html#SlicerLimitPrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.DcMin
  magneticalc.Wire_Widget.Wire_Widget.html#DcMin
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.DcMax
  magneticalc.Wire_Widget.Wire_Widget.html#DcMax
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.DcStep
  magneticalc.Wire_Widget.Wire_Widget.html#DcStep
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.DcPrecision
  magneticalc.Wire_Widget.Wire_Widget.html#DcPrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.__init__
  magneticalc.Wire_Widget.Wire_Widget.html#__init__
  Function
  Method
  PUBLIC
  Populates the widget.
- magneticalc.Wire_Widget.Wire_Widget.gui
  magneticalc.Wire_Widget.Wire_Widget.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.table
  magneticalc.Wire_Widget.Wire_Widget.html#table
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.table_total_label
  magneticalc.Wire_Widget.Wire_Widget.html#table_total_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.stretch_spinbox
  magneticalc.Wire_Widget.Wire_Widget.html#stretch_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_count_spinbox
  magneticalc.Wire_Widget.Wire_Widget.html#rotational_symmetry_count_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_radius_spinbox
  magneticalc.Wire_Widget.Wire_Widget.html#rotational_symmetry_radius_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_axis_combobox
  magneticalc.Wire_Widget.Wire_Widget.html#rotational_symmetry_axis_combobox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_offset_spinbox
  magneticalc.Wire_Widget.Wire_Widget.html#rotational_symmetry_offset_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.close_loop_checkbox
  magneticalc.Wire_Widget.Wire_Widget.html#close_loop_checkbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.transformed_total_label
  magneticalc.Wire_Widget.Wire_Widget.html#transformed_total_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.slicer_limit_spinbox
  magneticalc.Wire_Widget.Wire_Widget.html#slicer_limit_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.sliced_total_label
  magneticalc.Wire_Widget.Wire_Widget.html#sliced_total_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.dc_spinbox
  magneticalc.Wire_Widget.Wire_Widget.html#dc_spinbox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Widget.Wire_Widget.reload
  magneticalc.Wire_Widget.Wire_Widget.html#reload
  Function
  Method
  PUBLIC
  Reloads the widget.
- magneticalc.Wire_Widget.Wire_Widget.update
  magneticalc.Wire_Widget.Wire_Widget.html#update
  Function
  Method
  PUBLIC
  Updates the widget.
- magneticalc.Wire_Widget.Wire_Widget.update_labels
  magneticalc.Wire_Widget.Wire_Widget.html#update_labels
  Function
  Method
  PUBLIC
  Updates the labels.
- magneticalc.Wire_Widget.Wire_Widget.update_controls
  magneticalc.Wire_Widget.Wire_Widget.html#update_controls
  Function
  Method
  PUBLIC
  Updates the controls.
- magneticalc.Wire_Widget.Wire_Widget.update_table
  magneticalc.Wire_Widget.Wire_Widget.html#update_table
  Function
  Method
  PUBLIC
  Populates the table.
- magneticalc.Wire_Widget.Wire_Widget.on_table_row_added
  magneticalc.Wire_Widget.Wire_Widget.html#on_table_row_added
  Function
  Method
  PUBLIC
  Gets called after a row has been added to the table.
- magneticalc.Wire_Widget.Wire_Widget.on_table_cell_edited
  magneticalc.Wire_Widget.Wire_Widget.html#on_table_cell_edited
  Function
  Method
  PUBLIC
  Gets called after a table cell has been edited.
- magneticalc.Wire_Widget.Wire_Widget.on_table_row_deleted
  magneticalc.Wire_Widget.Wire_Widget.html#on_table_row_deleted
  Function
  Method
  PUBLIC
  Gets called after a row has been deleted from the table.
- magneticalc.Wire_Widget.Wire_Widget.set_stretch
  magneticalc.Wire_Widget.Wire_Widget.html#set_stretch
  Function
  Method
  PUBLIC
  Handles changes to stretch transform parameters.
- magneticalc.Wire_Widget.Wire_Widget.clear_stretch
  magneticalc.Wire_Widget.Wire_Widget.html#clear_stretch
  Function
  Method
  PUBLIC
  Clears the stretch values.
- magneticalc.Wire_Widget.Wire_Widget.update_stretch
  magneticalc.Wire_Widget.Wire_Widget.html#update_stretch
  Function
  Method
  PUBLIC
  Updates the stretch controls.
- magneticalc.Wire_Widget.Wire_Widget.set_rotational_symmetry
  magneticalc.Wire_Widget.Wire_Widget.html#set_rotational_symmetry
  Function
  Method
  PUBLIC
  Handles changes to rotational symmetry transform parameters.
- magneticalc.Wire_Widget.Wire_Widget.clear_rotational_symmetry
  magneticalc.Wire_Widget.Wire_Widget.html#clear_rotational_symmetry
  Function
  Method
  PUBLIC
  Clears the rotational symmetry values.
- magneticalc.Wire_Widget.Wire_Widget.update_rotational_symmetry
  magneticalc.Wire_Widget.Wire_Widget.html#update_rotational_symmetry
  Function
  Method
  PUBLIC
  Updates the rotational symmetry controls.
- magneticalc.Wire_Widget.Wire_Widget.set_wire
  magneticalc.Wire_Widget.Wire_Widget.html#set_wire
  Function
  Method
  PUBLIC
  Sets the wire. This will overwrite the currently set wire in the model. Any underscored parameter may be left set to None in order to load its default value.
- magneticalc.Wire_Presets.Wire_Presets
  magneticalc.Wire_Presets.Wire_Presets.html
  Class
  Class
  PUBLIC
  Wire_Presets class.
- magneticalc.Wire_Presets.Wire_Presets.StraightLine
  magneticalc.Wire_Presets.Wire_Presets.html#StraightLine
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.SingleSquareLoop_Offset
  magneticalc.Wire_Presets.Wire_Presets.html#SingleSquareLoop_Offset
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.SingleSquareLoop_Centered
  magneticalc.Wire_Presets.Wire_Presets.html#SingleSquareLoop_Centered
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.CompensatedDoubleSquareLoop_Offset
  magneticalc.Wire_Presets.Wire_Presets.html#CompensatedDoubleSquareLoop_Offset
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.CompensatedDoubleSquareLoop_Centered
  magneticalc.Wire_Presets.Wire_Presets.html#CompensatedDoubleSquareLoop_Centered
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.SingleCircularLoop_Offset
  magneticalc.Wire_Presets.Wire_Presets.html#SingleCircularLoop_Offset
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.SolenoidCircularLoops4
  magneticalc.Wire_Presets.Wire_Presets.html#SolenoidCircularLoops4
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.SolenoidCircularLoops8
  magneticalc.Wire_Presets.Wire_Presets.html#SolenoidCircularLoops8
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.CompensatedSolenoidCircularLoops4
  magneticalc.Wire_Presets.Wire_Presets.html#CompensatedSolenoidCircularLoops4
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.CompensatedSolenoidCircularLoops8
  magneticalc.Wire_Presets.Wire_Presets.html#CompensatedSolenoidCircularLoops8
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.get_phase_jumping_toroidal_loop
  magneticalc.Wire_Presets.Wire_Presets.html#get_phase_jumping_toroidal_loop
  Function
  Static Method
  PUBLIC
  Generates a (phase-jumping) toroidal loop.
- magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop8
  magneticalc.Wire_Presets.Wire_Presets.html#PhaseJumpingToroidalLoop8
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop16
  magneticalc.Wire_Presets.Wire_Presets.html#PhaseJumpingToroidalLoop16
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32HiRes
  magneticalc.Wire_Presets.Wire_Presets.html#PhaseJumpingToroidalLoop32HiRes
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32LoRes
  magneticalc.Wire_Presets.Wire_Presets.html#PhaseJumpingToroidalLoop32LoRes
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32HiResFlat
  magneticalc.Wire_Presets.Wire_Presets.html#PhaseJumpingToroidalLoop32HiResFlat
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32LoResFlat
  magneticalc.Wire_Presets.Wire_Presets.html#PhaseJumpingToroidalLoop32LoResFlat
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop8
  magneticalc.Wire_Presets.Wire_Presets.html#ToroidalLoop8
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop16
  magneticalc.Wire_Presets.Wire_Presets.html#ToroidalLoop16
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32HiRes
  magneticalc.Wire_Presets.Wire_Presets.html#ToroidalLoop32HiRes
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32LoRes
  magneticalc.Wire_Presets.Wire_Presets.html#ToroidalLoop32LoRes
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32HiResFlat
  magneticalc.Wire_Presets.Wire_Presets.html#ToroidalLoop32HiResFlat
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32LoResFlat
  magneticalc.Wire_Presets.Wire_Presets.html#ToroidalLoop32LoResFlat
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.List
  magneticalc.Wire_Presets.Wire_Presets.html#List
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Presets.Wire_Presets.get_by_id
  magneticalc.Wire_Presets.Wire_Presets.html#get_by_id
  Function
  Static Method
  PUBLIC
  Selects a preset by name.
- magneticalc.Wire_Menu.Wire_Menu
  magneticalc.Wire_Menu.Wire_Menu.html
  Class
  Class
  PUBLIC
  Wire_Menu class.
- magneticalc.Wire_Menu.Wire_Menu.__init__
  magneticalc.Wire_Menu.Wire_Menu.html#__init__
  Function
  Method
  PUBLIC
  Initializes the menu.
- magneticalc.Wire_Menu.Wire_Menu.gui
  magneticalc.Wire_Menu.Wire_Menu.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Menu.Wire_Menu.import_wire_action
  magneticalc.Wire_Menu.Wire_Menu.html#import_wire_action
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Menu.Wire_Menu.export_wire_action
  magneticalc.Wire_Menu.Wire_Menu.html#export_wire_action
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Wire_Menu.Wire_Menu.update
  magneticalc.Wire_Menu.Wire_Menu.html#update
  Function
  Method
  PUBLIC
  Updates the menu.
- magneticalc.Wire_Menu.Wire_Menu.wire_import
  magneticalc.Wire_Menu.Wire_Menu.html#wire_import
  Function
  Method
  PUBLIC
  Imports wire points from a TXT file.
- magneticalc.Wire_Menu.Wire_Menu.wire_export
  magneticalc.Wire_Menu.Wire_Menu.html#wire_export
  Function
  Method
  PUBLIC
  Exports wire points to a TXT file.
- magneticalc.Menu.Menu
  magneticalc.Menu.Menu.html
  Class
  Class
  PUBLIC
  Menu class.
- magneticalc.Menu.Menu.__init__
  magneticalc.Menu.Menu.html#__init__
  Function
  Method
  PUBLIC
  Creates the menu bar.
- magneticalc.Menu.Menu.gui
  magneticalc.Menu.Menu.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Menu.Menu.file_menu
  magneticalc.Menu.Menu.html#file_menu
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Menu.Menu.wire_menu
  magneticalc.Menu.Menu.html#wire_menu
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Menu.Menu.view_menu
  magneticalc.Menu.Menu.html#view_menu
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Menu.Menu.options_menu
  magneticalc.Menu.Menu.html#options_menu
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Menu.Menu.help_menu
  magneticalc.Menu.Menu.html#help_menu
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Menu.Menu.reload
  magneticalc.Menu.Menu.html#reload
  Function
  Method
  PUBLIC
  Reloads the menu.
- magneticalc.Menu.Menu.update
  magneticalc.Menu.Menu.html#update
  Function
  Method
  PUBLIC
  Updates all menus.
- magneticalc.Parameters.Parameters
  magneticalc.Parameters.Parameters.html
  Class
  Class
  PUBLIC
  Parameters class.
- magneticalc.Parameters.Parameters.__init__
  magneticalc.Parameters.Parameters.html#__init__
  Function
  Method
  PUBLIC
  Initializes parameters class.
- magneticalc.Parameters.Parameters._energy
  magneticalc.Parameters.Parameters.html#_energy
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Parameters.Parameters._self_inductance
  magneticalc.Parameters.Parameters.html#_self_inductance
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Parameters.Parameters._magnetic_dipole_moment
  magneticalc.Parameters.Parameters.html#_magnetic_dipole_moment
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Parameters.Parameters.set
  magneticalc.Parameters.Parameters.html#set
  Function
  Method
  PUBLIC
  Sets the parameters
- magneticalc.Parameters.Parameters._get_squared_field
  magneticalc.Parameters.Parameters.html#_get_squared_field
  Function
  Method
  PRIVATE
  Returns the "squared" field scalar.
- magneticalc.Parameters.Parameters._get_squared_field_worker
  magneticalc.Parameters.Parameters.html#_get_squared_field_worker
  Function
  Static Method
  PRIVATE
  Returns the "squared" field scalar.
- magneticalc.Parameters.Parameters._get_magnetic_dipole_moment
  magneticalc.Parameters.Parameters.html#_get_magnetic_dipole_moment
  Function
  Method
  PRIVATE
  Returns the magnetic dipole moment scalar.
- magneticalc.Parameters.Parameters._get_magnetic_dipole_moment_worker
  magneticalc.Parameters.Parameters.html#_get_magnetic_dipole_moment_worker
  Function
  Static Method
  PRIVATE
  Returns the (unscaled) magnetic dipole moment vector.
- magneticalc.Parameters.Parameters.recalculate
  magneticalc.Parameters.Parameters.html#recalculate
  Function
  Method
  PUBLIC
  Recalculates parameters.
- magneticalc.Parameters.Parameters.energy
  magneticalc.Parameters.Parameters.html#energy
  Attribute
  Property
  PUBLIC
  Returns calculated energy.
- magneticalc.Parameters.Parameters.self_inductance
  magneticalc.Parameters.Parameters.html#self_inductance
  Attribute
  Property
  PUBLIC
  Returns calculated self-inductance.
- magneticalc.Parameters.Parameters.magnetic_dipole_moment
  magneticalc.Parameters.Parameters.html#magnetic_dipole_moment
  Attribute
  Property
  PUBLIC
  Returns calculated magnetic dipole moment.
- magneticalc.Model.Model
  magneticalc.Model.Model.html
  Class
  Class
  PUBLIC
  Model class.
- magneticalc.Model.Model.DebugInvalidate
  magneticalc.Model.Model.html#DebugInvalidate
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Model.Model.__init__
  magneticalc.Model.Model.html#__init__
  Function
  Method
  PUBLIC
  Initializes the model.
- magneticalc.Model.Model.gui
  magneticalc.Model.Model.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Model.Model.wire
  magneticalc.Model.Model.html#wire
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Model.Model.sampling_volume
  magneticalc.Model.Model.html#sampling_volume
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Model.Model.metric
  magneticalc.Model.Model.html#metric
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Model.Model.parameters
  magneticalc.Model.Model.html#parameters
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Model.Model._field_type_select
  magneticalc.Model.Model.html#_field_type_select
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Model.Model._field_cache
  magneticalc.Model.Model.html#_field_cache
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Model.Model.field_type_select
  magneticalc.Model.Model.html#field_type_select
  Attribute
  Instance Variable
  PUBLIC
  Currently selected field type
- magneticalc.Model.Model.field_type_select.setter
  magneticalc.Model.Model.html#field_type_select.setter
  Function
  Method
  PUBLIC
  Sets the currently selected field type.
- magneticalc.Model.Model.field
  magneticalc.Model.Model.html#field
  Attribute
  Property
  PUBLIC
  Currently selected field
- magneticalc.Model.Model.get_valid_field
  magneticalc.Model.Model.html#get_valid_field
  Function
  Method
  PUBLIC
  Gets a field by type if the field is valid.
- magneticalc.Model.Model.valid
  magneticalc.Model.Model.html#valid
  Attribute
  Property
  PUBLIC
  True if model is valid, False otherwise
- magneticalc.Model.Model.invalidate
  magneticalc.Model.Model.html#invalidate
  Function
  Method
  PUBLIC
  Invalidates multiple hierarchy levels at once, in descending order of hierarchy.
- magneticalc.Model.Model.set_wire
  magneticalc.Model.Model.html#set_wire
  Function
  Method
  PUBLIC
  Sets the wire.
- magneticalc.Model.Model.set_sampling_volume
  magneticalc.Model.Model.html#set_sampling_volume
  Function
  Method
  PUBLIC
  Sets the sampling volume.
- magneticalc.Model.Model.set_field
  magneticalc.Model.Model.html#set_field
  Function
  Method
  PUBLIC
  Sets the field.
- magneticalc.Model.Model.set_metric
  magneticalc.Model.Model.html#set_metric
  Function
  Method
  PUBLIC
  Sets the metric.
- magneticalc.Model.Model.set_parameters
  magneticalc.Model.Model.html#set_parameters
  Function
  Method
  PUBLIC
  Sets the parameters.
- magneticalc.Model.Model.calculate_wire
  magneticalc.Model.Model.html#calculate_wire
  Function
  Method
  PUBLIC
  Calculates the wire.
- magneticalc.Model.Model.calculate_sampling_volume
  magneticalc.Model.Model.html#calculate_sampling_volume
  Function
  Method
  PUBLIC
  Calculates the sampling volume.
- magneticalc.Model.Model.calculate_field
  magneticalc.Model.Model.html#calculate_field
  Function
  Method
  PUBLIC
  Calculates the field.
- magneticalc.Model.Model.calculate_metric
  magneticalc.Model.Model.html#calculate_metric
  Function
  Method
  PUBLIC
  Calculates the metric.
- magneticalc.Model.Model.calculate_parameters
  magneticalc.Model.Model.html#calculate_parameters
  Function
  Method
  PUBLIC
  Calculates the parameters.
- magneticalc.Model.Model.on_wire_valid
  magneticalc.Model.Model.html#on_wire_valid
  Function
  Method
  PUBLIC
  Gets called when the wire was successfully calculated.
- magneticalc.Model.Model.on_sampling_volume_valid
  magneticalc.Model.Model.html#on_sampling_volume_valid
  Function
  Method
  PUBLIC
  Gets called when the sampling volume was successfully calculated.
- magneticalc.Model.Model.on_field_valid
  magneticalc.Model.Model.html#on_field_valid
  Function
  Method
  PUBLIC
  Gets called when the field was successfully calculated.
- magneticalc.Model.Model.on_metric_valid
  magneticalc.Model.Model.html#on_metric_valid
  Function
  Method
  PUBLIC
  Gets called when the metric was successfully calculated.
- magneticalc.Model.Model.on_parameters_valid
  magneticalc.Model.Model.html#on_parameters_valid
  Function
  Method
  PUBLIC
  Gets called when the parameters were successfully calculated.
- magneticalc.Model.Model.on_wire_invalid
  magneticalc.Model.Model.html#on_wire_invalid
  Function
  Method
  PUBLIC
  Gets called when the wire was invalidated.
- magneticalc.Model.Model.on_sampling_volume_invalid
  magneticalc.Model.Model.html#on_sampling_volume_invalid
  Function
  Method
  PUBLIC
  Gets called when the sampling volume was invalidated.
- magneticalc.Model.Model.on_field_invalid
  magneticalc.Model.Model.html#on_field_invalid
  Function
  Method
  PUBLIC
  Gets called when the field was invalidated.
- magneticalc.Model.Model.on_metric_invalid
  magneticalc.Model.Model.html#on_metric_invalid
  Function
  Method
  PUBLIC
  Gets called when the metric was invalidated.
- magneticalc.Model.Model.on_parameters_invalid
  magneticalc.Model.Model.html#on_parameters_invalid
  Function
  Method
  PUBLIC
  Gets called when the parameters were invalidated.
- magneticalc.Perspective_Presets.Perspective_Presets
  magneticalc.Perspective_Presets.Perspective_Presets.html
  Class
  Class
  PUBLIC
  Perspective_Presets class.
- magneticalc.Perspective_Presets.Perspective_Presets.Isometric
  magneticalc.Perspective_Presets.Perspective_Presets.html#Isometric
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Perspective_Presets.Perspective_Presets.PlaneXY
  magneticalc.Perspective_Presets.Perspective_Presets.html#PlaneXY
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Perspective_Presets.Perspective_Presets.PlaneXZ
  magneticalc.Perspective_Presets.Perspective_Presets.html#PlaneXZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Perspective_Presets.Perspective_Presets.PlaneYZ
  magneticalc.Perspective_Presets.Perspective_Presets.html#PlaneYZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Perspective_Presets.Perspective_Presets.List
  magneticalc.Perspective_Presets.Perspective_Presets.html#List
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Perspective_Presets.Perspective_Presets.get_by_id
  magneticalc.Perspective_Presets.Perspective_Presets.html#get_by_id
  Function
  Static Method
  PUBLIC
  Selects a preset by name.
- magneticalc.Project.Project
  magneticalc.Project.Project.html
  Class
  Class
  PUBLIC
  Project class.
- magneticalc.Project.Project.__init__
  magneticalc.Project.Project.html#__init__
  Function
  Method
  PUBLIC
  Initializes the project class.
- magneticalc.Project.Project.gui
  magneticalc.Project.Project.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Project.Project.open_default
  magneticalc.Project.Project.html#open_default
  Function
  Method
  PUBLIC
  Opens the default project.
- magneticalc.Project.Project.open
  magneticalc.Project.Project.html#open
  Function
  Method
  PUBLIC
  Opens a project from file.
- magneticalc.Project.Project.close
  magneticalc.Project.Project.html#close
  Function
  Method
  PUBLIC
  Attempts to close the project, but lets user choose to cancel closing, or save/discard changes if there are any.
- magneticalc.Project.Project.switch
  magneticalc.Project.Project.html#switch
  Function
  Method
  PUBLIC
  Closes the current project and opens another project.
- magneticalc.Project.Project.on_changed
  magneticalc.Project.Project.html#on_changed
  Function
  Method
  PUBLIC
  Gets called when the project changed.
- magneticalc.Project.Project.validate
  magneticalc.Project.Project.html#validate
  Function
  Method
  PUBLIC
  Validates the project.
- magneticalc.Project.Project.get_default
  magneticalc.Project.Project.html#get_default
  Function
  Static Method
  PUBLIC
  Gets the default project.
- magneticalc.SidebarLeft.SidebarLeft
  magneticalc.SidebarLeft.SidebarLeft.html
  Class
  Class
  PUBLIC
  SidebarLeft class.
- magneticalc.SidebarLeft.SidebarLeft.MaximumWidth
  magneticalc.SidebarLeft.SidebarLeft.html#MaximumWidth
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarLeft.SidebarLeft.VerticalSpacing
  magneticalc.SidebarLeft.SidebarLeft.html#VerticalSpacing
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarLeft.SidebarLeft.__init__
  magneticalc.SidebarLeft.SidebarLeft.html#__init__
  Function
  Method
  PUBLIC
  Populates the left sidebar.
- magneticalc.SidebarLeft.SidebarLeft.gui
  magneticalc.SidebarLeft.SidebarLeft.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarLeft.SidebarLeft.wire_widget
  magneticalc.SidebarLeft.SidebarLeft.html#wire_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarLeft.SidebarLeft.sampling_volume_widget
  magneticalc.SidebarLeft.SidebarLeft.html#sampling_volume_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets
  magneticalc.Metric_Presets.Metric_Presets.html
  Class
  Class
  PUBLIC
  Metric_Presets class.
- magneticalc.Metric_Presets.Metric_Presets.Magnitude
  magneticalc.Metric_Presets.Metric_Presets.html#Magnitude
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.MagnitudeX
  magneticalc.Metric_Presets.Metric_Presets.html#MagnitudeX
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.MagnitudeY
  magneticalc.Metric_Presets.Metric_Presets.html#MagnitudeY
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.MagnitudeZ
  magneticalc.Metric_Presets.Metric_Presets.html#MagnitudeZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.MagnitudeXY
  magneticalc.Metric_Presets.Metric_Presets.html#MagnitudeXY
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.MagnitudeXZ
  magneticalc.Metric_Presets.Metric_Presets.html#MagnitudeXZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.MagnitudeYZ
  magneticalc.Metric_Presets.Metric_Presets.html#MagnitudeYZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.Divergence
  magneticalc.Metric_Presets.Metric_Presets.html#Divergence
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.NegDivergence
  magneticalc.Metric_Presets.Metric_Presets.html#NegDivergence
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.PosDivergence
  magneticalc.Metric_Presets.Metric_Presets.html#PosDivergence
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.LogMagnitude
  magneticalc.Metric_Presets.Metric_Presets.html#LogMagnitude
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeX
  magneticalc.Metric_Presets.Metric_Presets.html#LogMagnitudeX
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeY
  magneticalc.Metric_Presets.Metric_Presets.html#LogMagnitudeY
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeZ
  magneticalc.Metric_Presets.Metric_Presets.html#LogMagnitudeZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeXY
  magneticalc.Metric_Presets.Metric_Presets.html#LogMagnitudeXY
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeXZ
  magneticalc.Metric_Presets.Metric_Presets.html#LogMagnitudeXZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeYZ
  magneticalc.Metric_Presets.Metric_Presets.html#LogMagnitudeYZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.LogDivergence
  magneticalc.Metric_Presets.Metric_Presets.html#LogDivergence
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.PosLogDivergence
  magneticalc.Metric_Presets.Metric_Presets.html#PosLogDivergence
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.NegLogDivergence
  magneticalc.Metric_Presets.Metric_Presets.html#NegLogDivergence
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.AngleXY
  magneticalc.Metric_Presets.Metric_Presets.html#AngleXY
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.AngleXZ
  magneticalc.Metric_Presets.Metric_Presets.html#AngleXZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.AngleYZ
  magneticalc.Metric_Presets.Metric_Presets.html#AngleYZ
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.List
  magneticalc.Metric_Presets.Metric_Presets.html#List
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Presets.Metric_Presets.get_by_id
  magneticalc.Metric_Presets.Metric_Presets.html#get_by_id
  Function
  Static Method
  PUBLIC
  Selects a preset by name.
- magneticalc.Metric_Widget.Metric_Widget
  magneticalc.Metric_Widget.Metric_Widget.html
  Class
  Class
  PUBLIC
  Metric_Widget class.
- magneticalc.Metric_Widget.Metric_Widget.ValuePrecision
  magneticalc.Metric_Widget.Metric_Widget.html#ValuePrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.Cool_Gradient_CSS
  magneticalc.Metric_Widget.Metric_Widget.html#Cool_Gradient_CSS
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.HSV_Gradient_CSS
  magneticalc.Metric_Widget.Metric_Widget.html#HSV_Gradient_CSS
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.__init__
  magneticalc.Metric_Widget.Metric_Widget.html#__init__
  Function
  Method
  PUBLIC
  Populates the widget.
- magneticalc.Metric_Widget.Metric_Widget.gui
  magneticalc.Metric_Widget.Metric_Widget.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.color_metric_combobox
  magneticalc.Metric_Widget.Metric_Widget.html#color_metric_combobox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.color_metric_limits_layout
  magneticalc.Metric_Widget.Metric_Widget.html#color_metric_limits_layout
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.color_metric_limits_widget
  magneticalc.Metric_Widget.Metric_Widget.html#color_metric_limits_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.color_metric_min_label
  magneticalc.Metric_Widget.Metric_Widget.html#color_metric_min_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.color_metric_max_label
  magneticalc.Metric_Widget.Metric_Widget.html#color_metric_max_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.alpha_metric_combobox
  magneticalc.Metric_Widget.Metric_Widget.html#alpha_metric_combobox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.alpha_metric_limits_layout
  magneticalc.Metric_Widget.Metric_Widget.html#alpha_metric_limits_layout
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.alpha_metric_limits_widget
  magneticalc.Metric_Widget.Metric_Widget.html#alpha_metric_limits_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.alpha_metric_min_label
  magneticalc.Metric_Widget.Metric_Widget.html#alpha_metric_min_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.alpha_metric_max_label
  magneticalc.Metric_Widget.Metric_Widget.html#alpha_metric_max_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Metric_Widget.Metric_Widget.reload
  magneticalc.Metric_Widget.Metric_Widget.html#reload
  Function
  Method
  PUBLIC
  Reloads the widget.
- magneticalc.Metric_Widget.Metric_Widget.update
  magneticalc.Metric_Widget.Metric_Widget.html#update
  Function
  Method
  PUBLIC
  Updates the widget.
- magneticalc.Metric_Widget.Metric_Widget.update_labels
  magneticalc.Metric_Widget.Metric_Widget.html#update_labels
  Function
  Method
  PUBLIC
  Updates the labels.
- magneticalc.Metric_Widget.Metric_Widget.update_controls
  magneticalc.Metric_Widget.Metric_Widget.html#update_controls
  Function
  Method
  PUBLIC
  Updates the controls.
- magneticalc.Metric_Widget.Metric_Widget.set_metric
  magneticalc.Metric_Widget.Metric_Widget.html#set_metric
  Function
  Method
  PUBLIC
  Sets the metric. This will overwrite the currently set metric in the model. Any underscored parameter may be left set to None in order to load its default value.
- magneticalc.Parameters_Widget.Parameters_Widget
  magneticalc.Parameters_Widget.Parameters_Widget.html
  Class
  Class
  PUBLIC
  Parameters_Widget class.
- magneticalc.Parameters_Widget.Parameters_Widget.ValuePrecision
  magneticalc.Parameters_Widget.Parameters_Widget.html#ValuePrecision
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.__init__
  magneticalc.Parameters_Widget.Parameters_Widget.html#__init__
  Function
  Method
  PUBLIC
  Populates the widget.
- magneticalc.Parameters_Widget.Parameters_Widget.gui
  magneticalc.Parameters_Widget.Parameters_Widget.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.wire_length_value_label
  magneticalc.Parameters_Widget.Parameters_Widget.html#wire_length_value_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.wire_length_units_label
  magneticalc.Parameters_Widget.Parameters_Widget.html#wire_length_units_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.magnetic_dipole_moment_value_label
  magneticalc.Parameters_Widget.Parameters_Widget.html#magnetic_dipole_moment_value_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.magnetic_dipole_moment_units_label
  magneticalc.Parameters_Widget.Parameters_Widget.html#magnetic_dipole_moment_units_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.energy_value_label
  magneticalc.Parameters_Widget.Parameters_Widget.html#energy_value_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.energy_units_label
  magneticalc.Parameters_Widget.Parameters_Widget.html#energy_units_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.self_inductance_value_label
  magneticalc.Parameters_Widget.Parameters_Widget.html#self_inductance_value_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.self_inductance_units_label
  magneticalc.Parameters_Widget.Parameters_Widget.html#self_inductance_units_label
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Parameters_Widget.Parameters_Widget.reload
  magneticalc.Parameters_Widget.Parameters_Widget.html#reload
  Function
  Method
  PUBLIC
  Reloads the widget.
- magneticalc.Parameters_Widget.Parameters_Widget.update
  magneticalc.Parameters_Widget.Parameters_Widget.html#update
  Function
  Method
  PUBLIC
  Updates the widget.
- magneticalc.Parameters_Widget.Parameters_Widget.update_labels
  magneticalc.Parameters_Widget.Parameters_Widget.html#update_labels
  Function
  Method
  PUBLIC
  Updates the labels.
- magneticalc.Parameters_Widget.Parameters_Widget.update_controls
  magneticalc.Parameters_Widget.Parameters_Widget.html#update_controls
  Function
  Method
  PUBLIC
  Updates the controls.
- magneticalc.Perspective_Widget.Perspective_Widget
  magneticalc.Perspective_Widget.Perspective_Widget.html
  Class
  Class
  PUBLIC
  Perspective_Widget class.
- magneticalc.Perspective_Widget.Perspective_Widget.__init__
  magneticalc.Perspective_Widget.Perspective_Widget.html#__init__
  Function
  Method
  PUBLIC
  Populates the widget.
- magneticalc.Perspective_Widget.Perspective_Widget.gui
  magneticalc.Perspective_Widget.Perspective_Widget.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Perspective_Widget.Perspective_Widget.reload
  magneticalc.Perspective_Widget.Perspective_Widget.html#reload
  Function
  Method
  PUBLIC
  Reloads the widget.
- magneticalc.Perspective_Widget.Perspective_Widget.set_perspective
  magneticalc.Perspective_Widget.Perspective_Widget.html#set_perspective
  Function
  Method
  PUBLIC
  Sets display perspective.
- magneticalc.SidebarRight.SidebarRight
  magneticalc.SidebarRight.SidebarRight.html
  Class
  Class
  PUBLIC
  SidebarRight class.
- magneticalc.SidebarRight.SidebarRight.MaximumWidth
  magneticalc.SidebarRight.SidebarRight.html#MaximumWidth
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarRight.SidebarRight.VerticalSpacing
  magneticalc.SidebarRight.SidebarRight.html#VerticalSpacing
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarRight.SidebarRight.__init__
  magneticalc.SidebarRight.SidebarRight.html#__init__
  Function
  Method
  PUBLIC
  Populates the right sidebar.
- magneticalc.SidebarRight.SidebarRight.gui
  magneticalc.SidebarRight.SidebarRight.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarRight.SidebarRight.field_widget
  magneticalc.SidebarRight.SidebarRight.html#field_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarRight.SidebarRight.metric_widget
  magneticalc.SidebarRight.SidebarRight.html#metric_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarRight.SidebarRight.parameters_widget
  magneticalc.SidebarRight.SidebarRight.html#parameters_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarRight.SidebarRight.perspective_widget
  magneticalc.SidebarRight.SidebarRight.html#perspective_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.SidebarRight.SidebarRight.display_widget
  magneticalc.SidebarRight.SidebarRight.html#display_widget
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Statusbar.Statusbar
  magneticalc.Statusbar.Statusbar.html
  Class
  Class
  PUBLIC
  Statusbar class.
- magneticalc.Statusbar.Statusbar.__init__
  magneticalc.Statusbar.Statusbar.html#__init__
  Function
  Method
  PUBLIC
  Initializes statusbar.
- magneticalc.Statusbar.Statusbar.gui
  magneticalc.Statusbar.Statusbar.html#gui
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Statusbar.Statusbar._valid
  magneticalc.Statusbar.Statusbar.html#_valid
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Statusbar.Statusbar._canceled
  magneticalc.Statusbar.Statusbar.html#_canceled
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Statusbar.Statusbar._start_button
  magneticalc.Statusbar.Statusbar.html#_start_button
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Statusbar.Statusbar._cancel_button
  magneticalc.Statusbar.Statusbar.html#_cancel_button
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Statusbar.Statusbar._auto_calculation_checkbox
  magneticalc.Statusbar.Statusbar.html#_auto_calculation_checkbox
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Statusbar.Statusbar._cores_combobox
  magneticalc.Statusbar.Statusbar.html#_cores_combobox
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Statusbar.Statusbar._progressbar
  magneticalc.Statusbar.Statusbar.html#_progressbar
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Statusbar.Statusbar._label
  magneticalc.Statusbar.Statusbar.html#_label
  Attribute
  Instance Variable
  PRIVATE
  Undocumented
- magneticalc.Statusbar.Statusbar.layout
  magneticalc.Statusbar.Statusbar.html#layout
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.Statusbar.Statusbar.reload
  magneticalc.Statusbar.Statusbar.html#reload
  Function
  Method
  PUBLIC
  Reloads the statusbar.
- magneticalc.Statusbar.Statusbar._auto_calculation_changed
  magneticalc.Statusbar.Statusbar.html#_auto_calculation_changed
  Function
  Method
  PRIVATE
  Handles changed auto-calculation setting.
- magneticalc.Statusbar.Statusbar.arm
  magneticalc.Statusbar.Statusbar.html#arm
  Function
  Method
  PUBLIC
  "Arms" the statusbar before calculation.
- magneticalc.Statusbar.Statusbar.disarm
  magneticalc.Statusbar.Statusbar.html#disarm
  Function
  Method
  PUBLIC
  "Disarms" the statusbar after calculation.
- magneticalc.Statusbar.Statusbar.invalidate
  magneticalc.Statusbar.Statusbar.html#invalidate
  Function
  Method
  PUBLIC
  "Invalidates" the statusbar.
- magneticalc.Statusbar.Statusbar.start
  magneticalc.Statusbar.Statusbar.html#start
  Function
  Method
  PUBLIC
  Starts the calculation.
- magneticalc.Statusbar.Statusbar.cancel
  magneticalc.Statusbar.Statusbar.html#cancel
  Function
  Method
  PUBLIC
  Cancels the ongoing calculation.
- magneticalc.Statusbar.Statusbar.set_text
  magneticalc.Statusbar.Statusbar.html#set_text
  Function
  Method
  PUBLIC
  Updates the statusbar text.
- magneticalc.Statusbar.Statusbar.set_progress
  magneticalc.Statusbar.Statusbar.html#set_progress
  Function
  Method
  PUBLIC
  Updates the progress percentage.
- magneticalc.Statusbar.Statusbar.set_progressbar_color
  magneticalc.Statusbar.Statusbar.html#set_progressbar_color
  Function
  Method
  PUBLIC
  Sets the progressbar color & style.
- magneticalc.GUI.GUI
  magneticalc.GUI.GUI.html
  Class
  Class
  PUBLIC
  GUI class.
- magneticalc.GUI.GUI.MinimumWindowSize
  magneticalc.GUI.GUI.html#MinimumWindowSize
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.calculation_status
  magneticalc.GUI.GUI.html#calculation_status
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.calculation_exited
  magneticalc.GUI.GUI.html#calculation_exited
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.invalidate_statusbar
  magneticalc.GUI.GUI.html#invalidate_statusbar
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.__init__
  magneticalc.GUI.GUI.html#__init__
  Function
  Method
  PUBLIC
  Initializes the GUI.
- magneticalc.GUI.GUI.initializing
  magneticalc.GUI.GUI.html#initializing
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.exiting
  magneticalc.GUI.GUI.html#exiting
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.user_locale
  magneticalc.GUI.GUI.html#user_locale
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.project
  magneticalc.GUI.GUI.html#project
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.calculation_thread
  magneticalc.GUI.GUI.html#calculation_thread
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.calculation_start_time
  magneticalc.GUI.GUI.html#calculation_start_time
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.statusbar
  magneticalc.GUI.GUI.html#statusbar
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.model
  magneticalc.GUI.GUI.html#model
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.sidebar_left
  magneticalc.GUI.GUI.html#sidebar_left
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.sidebar_right
  magneticalc.GUI.GUI.html#sidebar_right
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.vispy_canvas
  magneticalc.GUI.GUI.html#vispy_canvas
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.splitter
  magneticalc.GUI.GUI.html#splitter
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.menu
  magneticalc.GUI.GUI.html#menu
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- magneticalc.GUI.GUI.reload
  magneticalc.GUI.GUI.html#reload
  Function
  Method
  PUBLIC
  Reloads the GUI.
- magneticalc.GUI.GUI.re_wrapper
  magneticalc.GUI.GUI.html#re_wrapper
  Function
  Method
  PUBLIC
  Simple wrapper that decides between recalculation or redraw.
- magneticalc.GUI.GUI.redraw
  magneticalc.GUI.GUI.html#redraw
  Function
  Method
  PUBLIC
  Redraws the scene.
- magneticalc.GUI.GUI.recalculate
  magneticalc.GUI.GUI.html#recalculate
  Function
  Method
  PUBLIC
  Recalculates the model.
- magneticalc.GUI.GUI.interrupt_calculation
  magneticalc.GUI.GUI.html#interrupt_calculation
  Function
  Method
  PUBLIC
  Kills any running calculation.
- magneticalc.GUI.GUI.on_calculation_exited
  magneticalc.GUI.GUI.html#on_calculation_exited
  Function
  Method
  PUBLIC
  This is called after calculation thread has exited.
- magneticalc.GUI.GUI.keyPressEvent
  magneticalc.GUI.GUI.html#keyPressEvent
  Function
  Method
  PUBLIC
  Handles key press event.
- magneticalc.GUI.GUI.closeEvent
  magneticalc.GUI.GUI.html#closeEvent
  Function
  Method
  PUBLIC
  Gets called when the window is closed (programmatically through close() or manually)
- magneticalc.GUI.GUI.cleanup
  magneticalc.GUI.GUI.html#cleanup
  Function
  Method
  PUBLIC
  Perform clean-up upon quitting the application.
- magneticalc.__main__.main
  magneticalc.__main__.html#main
  Function
  Function
  PUBLIC
  MagnetiCalc main function.